@@ -77,6 +77,9 @@ LockStruct  LockProcs[] =
 	{"atlantis",
 	 25000, 4, 100, 6000, 64, 1.0, "",
 	 "Shows moving sharks/whales/dolphin", 0, NULL, "#ifdef USE_GL"},
+	{"atunnels",
+	 25000, 1, 1, 400, 64, 1.0, "",
+	 "Shows a n OpenGL advanced tunnel screensaver", 0, NULL, "#ifdef USE_GL"},
 #endif
 	{"ball",
 	 10000, 10, 20, -100, 64, 1.0, "",
@@ -159,7 +162,7 @@ LockStruct  LockProcs[] =
 	 "Shows a fading plot of sine squared", 0, NULL, NULL},
 #ifdef USE_GL
 	{"fire",
-	 10000, 800, 1, 1, 64, 1.0, "",
+	 10000, 800, 1, 400, 64, 1.0, "",
 	 "Shows a 3D fire-like image", 0, NULL, "#ifdef USE_GL"},
 #endif
 	{"flag",
@@ -304,6 +307,9 @@ LockStruct  LockProcs[] =
 	{"petal",
 	 10000, -500, 400, 1, 64, 1.0, "",
 	 "Shows various GCD Flowers", 0, NULL, NULL},
+	{"petri",
+	 10000, 1, 1, 4, 8, 1.0, "",
+	 "Shows a mold simulation in a petri dish", 0, NULL, NULL},
 #ifdef USE_GL
 	{"pipes",
 	 1000, 2, 5, 500, 64, 1.0, "",
@@ -399,7 +405,7 @@ LockStruct  LockProcs[] =
 	 "Shows 3D mathematical shapes", 0, NULL, "#ifdef USE_GL"},
 #endif
 	{"swarm",
-	 15000, -100, -100, 1, 64, 1.0, "",
+	 15000, -100, 1, -10, 64, 1.0, "",
 	 "Shows a swarm of bees following a wasp", 0, NULL, NULL},
 	{"swirl",
 	 5000, 5, 1, 1, 64, 1.0, "",
