@@ -132,10 +132,10 @@ typedef struct {
         double x, y;    /* euclidean bend times euclidean position */
 } circle;
 enum space {
-  euclidean = 0, spherical, hyperbolic
+  /* euclidean = 0, */ spherical = 1, hyperbolic = 2
 };
 
-const char * space_string[] = {
+static const char * space_string[] = {
   "euclidean",
   "spherical",
   "hyperbolic"
@@ -158,7 +158,7 @@ the label in the standard picture) then the "spherical label" is
 (e^2+x^2+y^2-1)/(2*e) (an integer!)  and the "hyperbolic label", is 
 calulated by h + s = e.
 */
-circle examples[][4] = {
+static circle examples[][4] = {
 { /* double semi-bounded */
 	{ 0, 0, 0,   0,  1},
 	{ 0, 0, 0,   0, -1},
@@ -451,7 +451,7 @@ geom(int geometry, int e, int p, int q)
 	if (g)
 		return (e*e + (1.0 - p*p - q*q) * g) / (2.0*e);
 	(void) printf("geom: g = 0\n");
-	return e;
+	return ((double) e);
 }
 
 static void
@@ -628,10 +628,14 @@ f(ModeInfo *mi, circle c1, circle c2, circle c3, circle c4)
 }
 
 static void
-free_apollonian(Display *display, apollonianstruct *cp)
+free_apollonian(
+#ifdef DOFONT
+		Display *display,
+#endif
+		apollonianstruct *cp)
 {
 	if (cp->quad != NULL) {
-		(void) free((void *) cp->quad);
+		free(cp->quad);
 		cp->quad = (apollonian_quadruple *) NULL;
 	}
 #ifdef DOFONT
@@ -647,7 +651,7 @@ free_apollonian(Display *display, apollonianstruct *cp)
 }
 
 #ifndef DEBUG
-void
+static void
 randomize_c(int randomize, circle * c)
 {
   if (randomize / 2) {
@@ -805,8 +809,12 @@ release_apollonian(ModeInfo * mi)
 		int         screen;
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
-			free_apollonian(MI_DISPLAY(mi), &apollonians[screen]);
-		(void) free((void *) apollonians);
+			free_apollonian(
+#ifdef DOFONT
+				MI_DISPLAY(mi),
+#endif
+				&apollonians[screen]);
+		free(apollonians);
 		apollonians = (apollonianstruct *) NULL;
 	}
 }
