@@ -578,7 +578,7 @@ free_crystal(Display *display, crystalstruct *cryst)
 		if (cryst->colors != NULL) {
 			if (cryst->ncolors && !cryst->no_colors)
 				free_colors(display, cryst->cmap, cryst->colors, cryst->ncolors);
-			(void) free((void *) cryst->colors);
+			free(cryst->colors);
 			cryst->colors = (XColor *) NULL;
 		}
 		if (cryst->cmap != None) {
@@ -591,7 +591,7 @@ free_crystal(Display *display, crystalstruct *cryst)
 		cryst->gc = None;
 	}
 	if (cryst->atom != NULL) {
-		(void) free((void *) cryst->atom);
+		free(cryst->atom);
 		cryst->atom = (crystalatom *) NULL;
 	}
 }
@@ -952,7 +952,7 @@ init_crystal(ModeInfo * mi)
 		if (cryst->colors != NULL) {
 			if (cryst->ncolors && !cryst->no_colors)
 				free_colors(display, cryst->cmap, cryst->colors, cryst->ncolors);
-			(void) free((void *) cryst->colors);
+			free(cryst->colors);
 			cryst->colors = (XColor *) NULL;
 		}
 		cryst->ncolors = MI_NCOLORS(mi);
@@ -1310,7 +1310,7 @@ release_crystal(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_crystal(MI_DISPLAY(mi), &crystals[screen]);
-		(void) free((void *) crystals);
+		free(crystals);
 		crystals = (crystalstruct *) NULL;
 	}
 }
