@@ -888,7 +888,7 @@ release_dclock(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_dclock(MI_DISPLAY(mi), &dclocks[screen]);
-		(void) free((void *) dclocks);
+		free(dclocks);
 		dclocks = (dclockstruct *) NULL;
 	}
 	free_font(MI_DISPLAY(mi));
