@@ -334,7 +334,7 @@ free_state(dilemmastruct * dp, int state)
 	while (dp->cellList[state]) {
 		current = dp->cellList[state];
 		dp->cellList[state] = dp->cellList[state]->next;
-		(void) free((void *) current);
+		free(current);
 	}
 	dp->cellList[state] = (CellList *) NULL;
 }
@@ -354,15 +354,15 @@ free_dilemma(dilemmastruct *dp)
 {
 	free_list(dp);
 	if (dp->sn != NULL) {
-		(void) free((void *) dp->sn);
+		free(dp->sn);
 		dp->sn = (char *) NULL;
 	}
 	if (dp->s != NULL) {
-		(void) free((void *) dp->s);
+		free(dp->s);
 		dp->s = (char *) NULL;
 	}
 	if (dp->payoff != NULL) {
-		(void) free((void *) dp->payoff);
+		free(dp->payoff);
 		dp->payoff = (float *) NULL;
 	}
 }
@@ -934,7 +934,7 @@ release_dilemma(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_dilemma(&dilemmas[screen]);
-		(void) free((void *) dilemmas);
+		free(dilemmas);
 		dilemmas = (dilemmastruct *) NULL;
 	}
 }
