@@ -482,7 +482,7 @@ ode_solve(euler2dstruct *sp)
   }
 }
 
-#define deallocate(p,t) if (p!=NULL) {(void) free((void *) p); p=(t*)NULL; }
+#define deallocate(p,t) if (p!=NULL) {free(p); p=(t*)NULL; }
 #define allocate(p,t,s) if ((p=(t*)malloc(sizeof(t)*s))==NULL)\
 {free_euler2d(sp);return;}
 
@@ -864,7 +864,7 @@ release_euler2d(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_euler2d(&euler2ds[screen]);
-		(void) free((void *) euler2ds);
+		free(euler2ds);
 		euler2ds = (euler2dstruct *) NULL;
 	}
 }
