@@ -545,7 +545,7 @@ init_atlantis(ModeInfo * mi)
 		if ((ap->sharks = (fishRec *) calloc(ap->num_sharks,
 						sizeof (fishRec))) == NULL) {
 			/* free everything up to now */
-			(void) free((void *) atlantis);
+			free(atlantis);
 			atlantis = (atlantisstruct *) NULL;
 			return;
 		}
@@ -627,13 +627,13 @@ release_atlantis(ModeInfo * mi)
 			atlantisstruct *ap = &atlantis[screen];
 
 			if (ap->sharks)
-				(void) free((void *) ap->sharks);
+				free(ap->sharks);
 			if (ap->texture)
 			{
 				XDestroyImage(ap->texture);
 			}
 		}
-		(void) free((void *) atlantis);
+		free(atlantis);
 		atlantis = (atlantisstruct *) NULL;
 	}
 	FreeAllGL(mi);
