@@ -291,7 +291,7 @@ setup_xbm_texture (unsigned char *bits, int width, int height,
   glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
 
   if (data != NULL) {
-	(void) free((void *) data);
+	free(data);
   }
 }
 
@@ -329,7 +329,7 @@ setup_file_texture (ModeInfo *mi, char *filename)
 	  break;
 
 	case XpmOpenFailed:
-	  fprintf (stderr, "Glplanet: file %s doesn't exist.\n", filename);
+	  (void) fprintf (stderr, "Glplanet: file %s doesn't exist.\n", filename);
 	  exit (-1);
 	  break;
 
@@ -338,12 +338,12 @@ setup_file_texture (ModeInfo *mi, char *filename)
 	  break;
 
 	case XpmNoMemory:
-	  fprintf (stderr, "Glplanet: XPM: out of memory\n");
+	  (void) fprintf (stderr, "Glplanet: XPM: out of memory\n");
 	  exit (-1);
 	  break;
 
 	default:
-	  fprintf (stderr, "Glplanet: XPM: unknown error code %d\n", result);
+	  (void) fprintf (stderr, "Glplanet: XPM: unknown error code %d\n", result);
 	  exit (-1);
 	  break;
 	}
@@ -362,9 +362,9 @@ setup_file_texture (ModeInfo *mi, char *filename)
 	if (status != Success)
 	  {
 #ifdef HAVE_XPM
-		fprintf (stderr, "Glplanet: not an XPM file: %s\n", filename);
+		(void) fprintf (stderr, "Glplanet: not an XPM file: %s\n", filename);
 # endif
-		fprintf (stderr, "Glplanet: not an XBM file: %s\n", filename);
+		(void) fprintf (stderr, "Glplanet: not an XBM file: %s\n", filename);
 		exit (1);
 	  }
 
@@ -373,10 +373,10 @@ setup_file_texture (ModeInfo *mi, char *filename)
 #else  /* !XMU */
 
 #ifdef HAVE_XPM
-  fprintf (stderr, "Glplanet: not an XPM file: %s\n", filename);
+  (void) fprintf (stderr, "Glplanet: not an XPM file: %s\n", filename);
 # endif
-  fprintf (stderr, "Glplanet: your vendor doesn't ship the standard Xmu library.\n");
-  fprintf (stderr, "Glplanet: we can't load XBM files without it.\n");
+  (void) fprintf (stderr, "Glplanet: your vendor doesn't ship the standard Xmu library.\n");
+  (void) fprintf (stderr, "Glplanet: we can't load XBM files without it.\n");
   exit (1);
 #endif /* !XMU */
 }
@@ -417,7 +417,8 @@ setup_face(void)
 }
 
 /* lame way to generate some random stars */
-void generate_stars(ModeInfo * mi, int width, int height)
+static void
+generate_stars(ModeInfo * mi, int width, int height)
 {
   int i;
 /*  GLfloat size_range[2], size;*/
@@ -427,7 +428,7 @@ void generate_stars(ModeInfo * mi, int width, int height)
   
 /*    glGetFloatv(GL_POINT_SIZE_RANGE, size_range); */
   
-/*    printf("size range: %f\t%f\n", size_range[0], size_range[1]); */
+/*    (void) printf("size range: %f\t%f\n", size_range[0], size_range[1]); */
   gp->starlist = glGenLists(1);
   glNewList(gp->starlist, GL_COMPILE);
 
@@ -667,17 +668,17 @@ init_glplanet(ModeInfo * mi)
 
     if (!XParseColor(MI_DISPLAY(mi), MI_COLORMAP(mi), f, &gp->fg))
       {
-		fprintf(stderr, "Glplanet: unparsable color: \"%s\"\n", f);
+		(void) fprintf(stderr, "Glplanet: unparsable color: \"%s\"\n", f);
 		exit(1);
       }
     if (!XParseColor(MI_DISPLAY(mi), MI_COLORMAP(mi), b, &gp->bg))
       {
-		fprintf(stderr, "Glplanet: unparsable color: \"%s\"\n", f);
+		(void) fprintf(stderr, "Glplanet: unparsable color: \"%s\"\n", f);
 		exit(1);
       }
 
-	(void) free((void *) f);
-	(void) free((void *) b);
+	free(f);
+	free(b);
   } 
 
 
@@ -768,7 +769,7 @@ release_glplanet(ModeInfo * mi)
 		  glDeleteLists(gp->starlist, 1);
 	  }
 	}
-	(void) free((void *) planets);
+	free(planets);
 	planets = (planetstruct *) NULL;
   }
   FreeAllGL(mi);
