@@ -240,7 +240,7 @@ myCone(float radius)
 }
 
 static Bool
-draw_moebius_ant(moebiusstruct * mp, float *Material, int mono)
+draw_moebius_ant(float *Material, int mono)
 {
 	static float ant_step = 0;
 	float       cos1 = cos(ant_step);
@@ -507,7 +507,7 @@ draw_moebius_strip(ModeInfo * mi)
 		glTranslatef(3, 0, 0);
 		glRotatef(mp->ant_position / 2 + 90, 0, 1, 0);
 		glTranslatef(0.28, 0, -0.45);
-		if (!draw_moebius_ant(mp, MaterialYellow, mono))
+		if (!draw_moebius_ant(MaterialYellow, mono))
 			return False;
 		glPopMatrix();
 
@@ -517,7 +517,7 @@ draw_moebius_strip(ModeInfo * mi)
 		glTranslatef(3, 0, 0);
 		glRotatef(mp->ant_position / 2, 0, 1, 0);
 		glTranslatef(0.28, 0, -0.45);
-		if (!draw_moebius_ant(mp, MaterialBlue, mono))
+		if (!draw_moebius_ant(MaterialBlue, mono))
 			return False;
 		glPopMatrix();
 
@@ -528,7 +528,7 @@ draw_moebius_strip(ModeInfo * mi)
 		glRotatef(-mp->ant_position / 2, 0, 1, 0);
 		glTranslatef(0.28, 0, 0.45);
 		glRotatef(180, 1, 0, 0);
-		if (!draw_moebius_ant(mp, MaterialGreen, mono))
+		if (!draw_moebius_ant(MaterialGreen, mono))
 			return False;
 		glPopMatrix();
 
@@ -539,7 +539,7 @@ draw_moebius_strip(ModeInfo * mi)
 		glRotatef(-mp->ant_position / 2 + 90, 0, 1, 0);
 		glTranslatef(0.28, 0, 0.45);
 		glRotatef(180, 1, 0, 0);
-		if (!draw_moebius_ant(mp, MaterialCyan, mono))
+		if (!draw_moebius_ant(MaterialCyan, mono))
 			return False;
 		glPopMatrix();
 	}
@@ -693,7 +693,7 @@ void
 release_moebius(ModeInfo * mi)
 {
 	if (moebius != NULL) {
-		(void) free((void *) moebius);
+		free(moebius);
 		moebius = (moebiusstruct *) NULL;
 	}
 	FreeAllGL(mi);
