@@ -122,7 +122,7 @@ static int scale_down;
 #define TUBE_FACES_2     3
 
 
-const char * const builtin_pdb_data[] = {
+static const char * const builtin_pdb_data[] = {
 # include "molecules.h"
 };
 
@@ -419,7 +419,7 @@ get_atom_data (const char *atom_name)
         break;
     }
 
-  free (n2);
+  free(n2);
   return d;
 }
 
@@ -904,7 +904,7 @@ parse_pdb_data (molecule *m, const char *data, const char *filename, int line)
           
           if (L > 99) L = 99;
 
-          strncpy(n2, s, L);
+          (void) strncpy(n2, s, L);
           n2 += 7;
           while (isspace((int) *n2)) n2++;
 
@@ -921,7 +921,7 @@ parse_pdb_data (molecule *m, const char *data, const char *filename, int line)
               !strcmp (n2 + strlen(n2) - 4, ".pdb"))
             n2[strlen(n2)-4] = 0;
 
-          if (m->label) free ((char *) m->label);
+          if (m->label) free((char *) m->label);
           m->label = (char *) strdup (n2);
           free(name);
         }
@@ -971,14 +971,14 @@ parse_pdb_data (molecule *m, const char *data, const char *filename, int line)
           char *name = (char *) calloc (1, 4);
           GLfloat x = -999, y = -999, z = -999;
 
-          sscanf (s+7, " %d ", &id);
+          (void) sscanf (s+7, " %d ", &id);
 
-          strncpy (name, s+12, 3);
+          (void) strncpy (name, s+12, 3);
           while (isspace((int) *name)) name++;
           ss = name + strlen(name)-1;
           while (isspace((int) *ss) && ss > name)
             *ss-- = 0;
-          sscanf (s + 32, " %f %f %f ", &x, &y, &z);
+          (void) sscanf (s + 32, " %f %f %f ", &x, &y, &z);
 /*
           (void) fprintf (stderr, "molecule: %s: %d: atom: %d \"%s\" %9.4f %9.4f %9.4f\n",
                    filename, line,
@@ -993,14 +993,14 @@ parse_pdb_data (molecule *m, const char *data, const char *filename, int line)
           char *name = (char *) calloc (1, 4);
           GLfloat x = -999, y = -999, z = -999;
 
-          sscanf (s+7, " %d ", &id);
+          (void) sscanf (s+7, " %d ", &id);
 
-          strncpy (name, s+12, 3);
+          (void) strncpy (name, s+12, 3);
           while (isspace((int) *name)) name++;
           ss = name + strlen(name)-1;
           while (isspace((int) *ss) && ss > name)
             *ss-- = 0;
-          sscanf (s + 30, " %f %f %f ", &x, &y, &z);
+          (void) sscanf (s + 30, " %f %f %f ", &x, &y, &z);
 /*
           (void) fprintf (stderr, "molecule: %s: %d: atom: %d \"%s\" %9.4f %9.4f %9.4f\n",
                    filename, line,
@@ -1073,7 +1073,7 @@ parse_pdb_file (molecule *m, const char *name)
     }
 
   free (buf);
-  fclose (in);
+  (void) fclose (in);
 
   if (!m->natoms)
     {
@@ -1112,7 +1112,7 @@ generate_molecule_formula (molecule *m)
       while (counts[j].atom && !!strcmp(a, counts[j].atom))
         j++;
       if (counts[j].atom)
-        free (a);
+        free(a);
       else
         counts[j].atom = a;
       counts[j].count++;
@@ -1121,8 +1121,8 @@ generate_molecule_formula (molecule *m)
   i = 0;
   while (counts[i].atom)
     {
-      strcat (s, counts[i].atom);
-      free (counts[i].atom);
+      (void) strcat (s, counts[i].atom);
+      free(counts[i].atom);
       s += strlen (s);
       if (counts[i].count > 1)
         (void) sprintf (s, "(%d)", counts[i].count);
@@ -1132,10 +1132,10 @@ generate_molecule_formula (molecule *m)
 
   if (!m->label) m->label = (char *) strdup("");
   s = (char *) malloc (strlen (m->label) + strlen (buf) + 2);
-  strcpy (s, m->label);
-  strcat (s, "\n");
-  strcat (s, buf);
-  free ((char *) m->label);
+  (void) strcpy (s, m->label);
+  (void) strcat (s, "\n");
+  (void) strcat (s, buf);
+  free((char*) m->label);
   free (buf);
   m->label = s;
 }
@@ -1234,7 +1234,7 @@ reshape_molecule (ModeInfo *mi, int width, int height)
 
 
 static void
-gl_init (ModeInfo *mi)
+gl_init()
 {
   static GLfloat pos[4] = {5.0, 5.0, 10.0, 1.0};
   glLightfv(GL_LIGHT0, GL_POSITION, pos);
@@ -1364,7 +1364,7 @@ init_molecule (ModeInfo *mi)
 
   if ((mc->glx_context = init_GL(mi)) != NULL) {
     glDrawBuffer(GL_BACK);
-    gl_init(mi);
+    gl_init();
     last = 0;
     reshape_molecule (mi, MI_WIDTH(mi), MI_HEIGHT(mi));
   }
@@ -1558,20 +1558,20 @@ release_molecule(ModeInfo * mi)
 	    molecule *m = &mc->molecules[i];
 
 	    if (m->atoms) {
-		(void) free ((void *) m->atoms);
+		free(m->atoms);
 		m->atoms = (molecule_atom *) NULL;
 	    }
 	    if (m->bonds) {
-		(void) free ((void *) m->bonds);
+		free(m->bonds);
 		m->bonds = (molecule_bond *) NULL;
 	    }
 	    if (m->label) {
-		(void) free ((void *) m->label);
+		free(m->label);
 		m->label = (char *) NULL;
 	    }
 	  }
 	  if (mc->molecules) {
-		(void) free ((void *) mc->molecules);
+		free(mc->molecules);
 		mc->molecules = (molecule *) NULL;
 	  }
 #endif
@@ -1583,7 +1583,7 @@ release_molecule(ModeInfo * mi)
 		free_fonts (mi);
 	  }
 	}
-	(void) free((void *) mcs);
+	free(mcs);
 	mcs = (molecule_configuration *) NULL;
   }
   FreeAllGL(mi);
