@@ -846,7 +846,7 @@ void
 release_morph3d(ModeInfo * mi)
 {
 	if (morph3d != NULL) {
-		(void) free((void *) morph3d);
+		free(morph3d);
 		morph3d = (morph3dstruct *) NULL;
 	}
 	FreeAllGL(mi);
