@@ -543,7 +543,7 @@ sizeRow(rubikstruct * rp, int face)
 }
 
 static Bool
-draw_stickerless_cubit(rubikstruct *rp)
+draw_stickerless_cubit()
 {
 	glBegin(GL_QUADS);
 	glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray);
@@ -684,10 +684,9 @@ static Bool
 draw_cubit(ModeInfo * mi,
 	   int back, int front, int left, int right, int bottom, int top)
 {
-	rubikstruct *rp = &rubik[MI_SCREEN(mi)];
 	int         mono = MI_IS_MONO(mi);
 
-	if (!draw_stickerless_cubit(rp))
+	if (!draw_stickerless_cubit())
 		return False;
 	if (back != NO_FACE) {
 		glBegin(GL_POLYGON);
@@ -1454,7 +1453,7 @@ rotateFace(rubikstruct * rp, int face, int direction)
 		/* DrawSquare(face, position); */
 	}
 	if (faceLoc != NULL)
-		(void) free((void *) faceLoc);
+		free(faceLoc);
 	return True;
 }
 
@@ -1722,7 +1721,7 @@ shuffle(ModeInfo * mi)
 
 	for (face = 0; face < MAXFACES; face++) {
 		if (rp->cubeLoc[face] != NULL)
-			(void) free((void *) rp->cubeLoc[face]);
+			free(rp->cubeLoc[face]);
 		if ((rp->cubeLoc[face] = (RubikLoc *) malloc(sizeFace(rp, face) *
 				sizeof (RubikLoc))) == NULL) {
 			return False;
@@ -1734,7 +1733,7 @@ shuffle(ModeInfo * mi)
 	}
 	for (i = 0; i < MAXORIENT; i++) {
 		if (rp->rowLoc[i] != NULL)
-			(void) free((void *) rp->rowLoc[i]);
+			free(rp->rowLoc[i]);
 		/* The following is reused so make it the biggest size */
 		if ((rp->rowLoc[i] = (RubikLoc *) malloc(MAXMAXSIZE *
 				sizeof (RubikLoc))) == NULL) {
@@ -1744,7 +1743,7 @@ shuffle(ModeInfo * mi)
 	rp->storedmoves = MI_COUNT(mi);
 	if (rp->storedmoves < 0) {
 		if (rp->moves != NULL)
-			(void) free((void *) rp->moves);
+			free(rp->moves);
 		rp->moves = (RubikMove *) NULL;
 		rp->storedmoves = NRAND(-rp->storedmoves) + 1;
 	}
@@ -1852,16 +1851,16 @@ free_rubik(rubikstruct *rp)
 
 	for (i = 0; i < MAXFACES; i++)
 		if (rp->cubeLoc[i] != NULL) {
-			(void) free((void *) rp->cubeLoc[i]);
+			free(rp->cubeLoc[i]);
 			rp->cubeLoc[i] = (RubikLoc *) NULL;
 		}
 	for (i = 0; i < MAXORIENT; i++)
 		if (rp->rowLoc[i] != NULL) {
-			(void) free((void *) rp->rowLoc[i]);
+			free(rp->rowLoc[i]);
 			rp->rowLoc[i] = (RubikLoc *) NULL;
 		}
 	if (rp->moves != NULL) {
-		(void) free((void *) rp->moves);
+		free(rp->moves);
 		rp->moves = (RubikMove *) NULL;
 	}
 }
@@ -1877,7 +1876,7 @@ release_rubik(ModeInfo * mi)
 
 			free_rubik(rp);
 		}
-		(void) free((void *) rubik);
+		free(rubik);
 		rubik = (rubikstruct *) NULL;
 	}
 	FreeAllGL(mi);
