@@ -1277,7 +1277,7 @@ shuffle(ModeInfo * mi)
 	sp->storedmoves = MI_COUNT(mi);
 	if (sp->storedmoves < 0) {
 		if (sp->moves != NULL)
-			(void) free((void *) sp->moves);
+			free(sp->moves);
 		sp->moves = (SkewbMove *) NULL;
 		sp->storedmoves = NRAND(-sp->storedmoves) + 1;
 	}
@@ -1370,7 +1370,7 @@ static void
 free_skewb(skewbstruct *sp)
 {
 	if (sp->moves != NULL) {
-		(void) free((void *) sp->moves);
+		free(sp->moves);
 		sp->moves = (SkewbMove *) NULL;
 	}
 }
@@ -1386,7 +1386,7 @@ release_skewb(ModeInfo * mi)
 
 			free_skewb(sp);
 		}
-		(void) free((void *) skewb);
+		free(skewb);
 		skewb = (skewbstruct *) NULL;
         }
 	FreeAllGL(mi);
