@@ -701,11 +701,11 @@ CleanupSproingies(int screen)
 	}
 	if (si->positions) {
 		--active_screens;
-		(void) free((void *) (si->positions));
+		free((si->positions));
 		si->positions = (struct sPosColor *) NULL;
 	}
 	if ((active_screens == 0) && si_list) {
-		(void) free((void *) (si_list));
+		free((si_list));
 		si_list = (sp_instance *) NULL;
 	}
 }
