@@ -743,7 +743,7 @@ static void
     }
 
     if (!nosplit)
-	(void) free((void *) c_text);
+	free(c_text);
     if (size_x == 0.0)
     {
 	(void) fprintf(stderr, "Please give something to draw !\n");
@@ -1219,7 +1219,7 @@ void
 	    if (tp->face)
 		delete tp->face;
 	}
-	(void) free((void *) text3d);
+	free(text3d);
 	text3d = (text3dstruct *) NULL;
     }
     FreeAllGL(mi);
