@@ -547,9 +547,9 @@ release_hop(ModeInfo * mi)
 			hopstruct  *hp = &hops[screen];
 
 			if (hp->pointBuffer != NULL)
-				(void) free((void *) hp->pointBuffer);
+				free(hp->pointBuffer);
 		}
-		(void) free((void *) hops);
+		free(hops);
 		hops = (hopstruct *) NULL;
 	}
 }
