@@ -348,15 +348,15 @@ static void
 free_hyperstuff(hyperstruct * hp)
 {
 	if (hp->axis_points) {
-		(void) free((void *) hp->axis_points);
+		free(hp->axis_points);
 		hp->axis_points = (int *) NULL;
 	}
 	if (hp->points) {
-		(void) free((void *) hp->points);
+		free(hp->points);
 		hp->points = (vector *) NULL;
 	}
 	if (hp->pointsleft) {
-		(void) free((void *) hp->pointsleft);
+		free(hp->pointsleft);
 		hp->pointsleft = (vector *) NULL;
 	}
 	if (hp->lines) {
@@ -372,35 +372,35 @@ free_hyperstuff(hyperstruct * hp)
 		hp->rotation_planes = (XPoint *) NULL;
 	}
 	if (hp->rotations) {
-		(void) free((void *) hp->rotations);
+		free(hp->rotations);
 		hp->rotations = (double *) NULL;
 	}
 	if (hp->d_rotations) {
-		(void) free((void *) hp->d_rotations);
+		free(hp->d_rotations);
 		hp->d_rotations = (double *) NULL;
 	}
 	if (hp->dd_rotations) {
-		(void) free((void *) hp->dd_rotations);
+		free(hp->dd_rotations);
 		hp->dd_rotations = (double *) NULL;
 	}
 	if (hp->cdd_rotations) {
-		(void) free((void *) hp->cdd_rotations);
+		free(hp->cdd_rotations);
 		hp->cdd_rotations = (int *) NULL;
 	}
 	if (hp->Trotations) {
-		(void) free((void *) hp->Trotations);
+		free(hp->Trotations);
 		hp->Trotations = (matrix *) NULL;
 	}
 	if (hp->Trotationsleft) {
-		(void) free((void *) hp->Trotationsleft);
+		free(hp->Trotationsleft);
 		hp->Trotationsleft = (matrix *) NULL;
 	}
 	if (hp->Tall) {
-		(void) free((void *) hp->Tall);
+		free(hp->Tall);
 		hp->Tall = (matrix *) NULL;
 	}
 	if (hp->Tallleft) {
-		(void) free((void *) hp->Tallleft);
+		free(hp->Tallleft);
 		hp->Tallleft = (matrix *) NULL;
 	}
 	if (hp->xpoints[0]) {
@@ -470,7 +470,7 @@ figure_points(ModeInfo * mi)
 		}
 		n++;
 	} while (IncMultiCounter(c, hp->num_d));
-	(void) free((void *) c);
+	free(c);
 #if DEBUG
 	assert(hp->num_points == n);
 #endif
@@ -976,28 +976,28 @@ calc_transformation(ModeInfo * mi)
 			(Tpretranspose == NULL) || (Tscale == NULL) ||
 			(Tposttranspose == NULL)) {
 		if (Ttmp == NULL)	
-			(void) free((void *) Ttmp);
+			free(Ttmp);
 		if (Tpre == NULL)	
-			(void) free((void *) Tpre);
+			free(Tpre);
 		if (Tuser == NULL)	
-			(void) free((void *) Tuser);
+			free(Tuser);
 		if (Tpretranspose == NULL)	
-			(void) free((void *) Tpretranspose);
+			free(Tpretranspose);
 		if (Tscale == NULL)	
-			(void) free((void *) Tscale);
+			free(Tscale);
 		if (Tposttranspose == NULL)	
-			(void) free((void *) Tposttranspose);
+			free(Tposttranspose);
 		return False;
 	}
 	if (MI_IS_USE3D(mi)) {
 		if ((Tuserleft = (matrix *) malloc(hp->num_matmat *
 				sizeof (matrix))) == NULL) {
-			(void) free((void *) Ttmp);
-			(void) free((void *) Tpre);
-			(void) free((void *) Tuser);
-			(void) free((void *) Tpretranspose);
-			(void) free((void *) Tscale);
-			(void) free((void *) Tposttranspose);
+			free(Ttmp);
+			free(Tpre);
+			free(Tuser);
+			free(Tpretranspose);
+			free(Tscale);
+			free(Tposttranspose);
 			return False;
 		}
 	}
@@ -1090,23 +1090,23 @@ calc_transformation(ModeInfo * mi)
 #else
 	MatIdent(Tscale, hp->num_mat);
 #endif
-	(void) free((void *) Tpretranspose);
-	(void) free((void *) Tposttranspose);
+	free(Tpretranspose);
+	free(Tposttranspose);
 
 	/*
 	 * Put it all together.
 	 */
 	MatMult(Tuser, Tpre, Ttmp, hp->num_mat);
 	MatMult(Tscale, Ttmp, hp->Tall, hp->num_mat);
-	(void) free((void *) Tuser);
+	free(Tuser);
 	if (MI_IS_USE3D(mi)) {
 		MatMult(Tuserleft, Tpre, Ttmp, hp->num_mat);
 		MatMult(Tscale, Ttmp, hp->Tallleft, hp->num_mat);
-		(void) free((void *) Tuserleft);
+		free(Tuserleft);
 	}
-	(void) free((void *) Tpre);
-	(void) free((void *) Ttmp);
-	(void) free((void *) Tscale);
+	free(Tpre);
+	free(Ttmp);
+	free(Tscale);
 	return True;
 }
 
@@ -1122,7 +1122,7 @@ translate_point(hyperstruct * hp, matrix * Tall, vector * real, XPoint * screen_
 	screen_image->x = (short) image[0];
 	screen_image->y = (short) image[1];
 
-	(void) free((void *) image);
+	free(image);
 	return True;
 }
 
@@ -1253,7 +1253,7 @@ release_hyper(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_hyper(MI_DISPLAY(mi), &hypers[screen]);
-		(void) free((void *) hypers);
+		free(hypers);
 		hypers = (hyperstruct *) NULL;
 	}
 }
