@@ -383,7 +383,7 @@ static patternstruct portfolio[] = {
 #define REMOVE(t)						\
   (t)->next->prev = (t)->prev;					\
   (t)->prev->next = (t)->next;					\
-  (void) free((void *) t)
+  free(t)
 
 static void
 free_pattern(jugglestruct *sp) {
@@ -393,7 +393,7 @@ free_pattern(jugglestruct *sp) {
 
 			REMOVE(t); /* don't eliminate t */
 		}
-		(void) free((void *) sp->head);
+		free(sp->head);
   		sp->head = (Trajectory *) NULL;
 	}
 }
@@ -402,7 +402,7 @@ static void
 free_juggle(jugglestruct *sp)
 {
 	if (sp->trace != NULL) {
-		(void) free((void *) sp->trace);
+		free(sp->trace);
 		sp->trace = (XPoint *) NULL;
 	}
 	free_pattern(sp);
@@ -1110,11 +1110,11 @@ release_juggle(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_juggle(&juggles[screen]);
-		(void) free((void *) juggles);
+		free(juggles);
 		juggles = (jugglestruct *) NULL;
 	}
 	if (patternindex != NULL) {
-		(void) free((void *) patternindex);
+		free(patternindex);
 		patternindex = (PatternIndex *) NULL;
 	}
 }
