@@ -2084,7 +2084,7 @@ init_list(lifestruct * lp, int state)
 		return False;
 	}
 	if ((lp->first[state] = (CellList *) malloc(sizeof (CellList))) == NULL) {
-		(void) free((void *) lp->last[state]);
+		free(lp->last[state]);
 		lp->last[state] = (CellList *) NULL;
 		return False;
 	}
@@ -2124,7 +2124,7 @@ removefrom_list(lifestruct * lp, int state, CellList * curr)
 		lp->arr[curr->info.position] = (CellList *) NULL;
 		lp->ncells[state]--;
 	}
-	(void) free((void *) curr);
+	free(curr);
 }
 
 #ifdef DEBUG
@@ -2156,7 +2156,7 @@ flush_list(lifestruct * lp, int state)
 
 		curr->previous->next = lp->last[state];
 		lp->last[state]->previous = curr->previous;
-		(void) free((void *) curr);
+		free(curr);
 	}
 	lp->ncells[state] = 0;
 }
@@ -2254,7 +2254,7 @@ static void
 free_cells(lifestruct * lp)
 {
 	if (lp->arr != NULL) {
-		(void) free((void *) lp->arr);
+		free(lp->arr);
 		lp->arr = (CellList **) NULL;
 	}
 }
@@ -2282,10 +2282,10 @@ free_life(Display * display, lifestruct * lp)
 		if (lp->first[state])
 			flush_list(lp, state);
 		if (lp->last[state])
-			(void) free((void *) lp->last[state]);
+			free(lp->last[state]);
 		lp->last[state] = (CellList *) NULL;
 		if (lp->first[state])
-			(void) free((void *) lp->first[state]);
+			free(lp->first[state]);
 		lp->first[state] = (CellList *) NULL;
 	}
 	free_cells(lp);
@@ -3188,7 +3188,7 @@ release_life(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_life(MI_DISPLAY(mi), &lifes[screen]);
-		(void) free((void *) lifes);
+		free(lifes);
 		lifes = (lifestruct *) NULL;
 	}
 }
