@@ -1454,7 +1454,7 @@ DelFromEraseList(CellList * cell)
 {
 	cell->next->prev = cell->prev;
 	cell->prev->next = cell->next;
-	(void) free((void *) cell);
+	free(cell);
 }
 
 /*--- memory ---*/
@@ -1469,7 +1469,7 @@ MemInit(life3dstruct * lp)
 
 	for (i = 0; i < BASESIZE; ++i) {
 		if (lp->base[i] != NULL) {
-			(void) free((void *) lp->base[i]);
+			free(lp->base[i]);
 			lp->base[i] = (unsigned char *) NULL;
 		}
 	}
@@ -1533,7 +1533,7 @@ ClearMem(life3dstruct * lp)
 				if (CellState3D(lp->base[i][j]))
 					++count;
 			if (!count) {
-				(void) free((void *) lp->base[i]);
+				free(lp->base[i]);
 				lp->base[i] = (unsigned char *) NULL;
 			}
 		}
@@ -2255,7 +2255,7 @@ release_life3d(ModeInfo * mi)
 			if (lp->eraserhead.next != NULL)
 				End3D(lp);
 		}
-		(void) free((void *) life3ds);
+		free(life3ds);
 		life3ds = (life3dstruct *) NULL;
 	}
 }
