@@ -663,7 +663,7 @@ release_mandelbrot(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_mandelbrot(MI_DISPLAY(mi), &mandels[screen]);
-		(void) free((void *) mandels);
+		free(mandels);
 		mandels = (mandelstruct *) NULL;
 	}
 }
