@@ -309,19 +309,19 @@ static void
 free_path(mazestruct * mp)
 {
 	if (mp->maze) {
-		(void) free((void *) mp->maze);
+		free(mp->maze);
 		mp->maze = (unsigned short *) NULL;
 	}
 	if (mp->move_list) {
-		(void) free((void *) mp->move_list);
+		free(mp->move_list);
 		mp->move_list = (paths *) NULL;
 	}
 	if (mp->save_path) {
-		(void) free((void *) mp->save_path);
+		free(mp->save_path);
 		mp->save_path = (paths *) NULL;
 	}
 	if (mp->path) {
-		(void) free((void *) mp->path);
+		free(mp->path);
 		mp->path = (paths *) NULL;
 	}
 }
@@ -744,12 +744,10 @@ draw_maze_border(ModeInfo * mi)
 	draw_solid_square(mi, gc, mp->end_x, mp->end_y, mp->end_dir);
 }				/* end of draw_maze() */
 
-void
+static void
 try_to_move(ModeInfo *mi, int dir)
 {                               /* based on solve_maze */
 	mazestruct *mp = &mazes[MI_SCREEN(mi)];
-	Display    *display = MI_DISPLAY(mi);
-	Window      window = MI_WINDOW(mi);
 	int colliding = mp->maze[mp->path[mp->current_path].x * mp->nrows +
 		mp->path[mp->current_path].y] &
 		(WALL_TOP >> dir); /*  Are we trying to go through a wall? */
@@ -762,7 +760,7 @@ try_to_move(ModeInfo *mi, int dir)
 		enter_square(mi, mp->current_path);
 		mp->current_path++;
 #if 0
-		fprintf(stderr,
+		(void) fprintf(stderr,
 	"Calling draw_solid_square with params: x=%d, y= %d, dir=%d\n",
 			(int) (mp->path[mp->current_path].x),
 			(int) (mp->path[mp->current_path].y),
@@ -800,8 +798,8 @@ try_to_move(ModeInfo *mi, int dir)
 #if 0
 		else {
 			/* Beep if we can't go in that direction */
-			fprintf(stdout, "\a");
-			fflush(stdout);
+			(void) fprintf(stdout, "\a");
+			(void) fflush(stdout);
 		}
 #endif
 	}
@@ -1050,7 +1048,7 @@ release_maze(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_maze(MI_DISPLAY(mi), &mazes[screen]);
-		(void) free((void *) mazes);
+		free(mazes);
 		mazes = (mazestruct *) NULL;
 	}
 }
