@@ -399,13 +399,13 @@ free_penrose(tiling_c * tp)
 	do {
 		fp2 = fp1;
 		fp1 = fp1->next;
-		(void) free((void *) fp2);
+		free(fp2);
 	} while (fp1 != tp->fringe.nodes);
 	tp->fringe.nodes = (fringe_node_c *) NULL;
 	for (lp1 = tp->forced.first; lp1 != 0;) {
 		lp2 = lp1;
 		lp1 = lp1->next;
-		(void) free((void *) lp2);
+		free(lp2);
 	}
 	tp->forced.first = 0;
 }
@@ -751,7 +751,7 @@ check_vertex(ModeInfo * mi, fringe_node_c * vertex, tiling_c * tp)
 			*vertex->list_ptr = node->next;
 			if (node->next != 0)
 				node->next->vertex->list_ptr = vertex->list_ptr;
-			(void) free((void *) node);
+			free(node);
 			tp->forced.n_nodes--;
 			if (!vertex->off_screen)
 				tp->forced.n_visible--;
@@ -802,14 +802,14 @@ delete_vertex(ModeInfo * mi, fringe_node_c * vertex, tiling_c * tp)
 		*vertex->list_ptr = node->next;
 		if (node->next != 0)
 			node->next->vertex->list_ptr = vertex->list_ptr;
-		(void) free((void *) node);
+		free(node);
 		tp->forced.n_nodes--;
 		if (!vertex->off_screen)
 			tp->forced.n_visible--;
 	}
 	if (!vertex->off_screen)
 		tp->fringe.n_nodes--;
-	(void) free((void *) vertex);
+	free(vertex);
 }
 
 
@@ -1320,7 +1320,7 @@ release_penrose(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_penrose(&tilings[screen]);
-		(void) free((void *) tilings);
+		free(tilings);
 		tilings = (tiling_c *) NULL;
 	}
 }
