@@ -141,6 +141,9 @@ static char gl_modes[][MAXMODECHARS] =
 #ifdef MODE_atlantis
 	"atlantis",
 #endif
+#ifdef MODE_atunnels
+	"atunnels",
+#endif
 #ifdef MODE_bubble3d
 	"bubble3d",
 #endif
@@ -199,7 +202,7 @@ static char gl_modes[][MAXMODECHARS] =
 	"superquadrics",
 #endif
 #ifdef MODE_text3d
-	"text3d"
+	"text3d",
 #endif
 };
 
@@ -364,6 +367,9 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_petal
 	"petal",
 #endif
+#ifdef MODE_petri
+	"petri",
+#endif
 #ifdef MODE_puzzle
 	"puzzle",
 #endif
@@ -511,6 +517,9 @@ static char automata_modes[][MAXMODECHARS] =
 #ifdef MODE_loop
 	"loop",
 #endif
+#ifdef MODE_petri
+	"petri",
+#endif
 #ifdef MODE_voters
 	"voters",
 #endif
