@@ -152,7 +152,7 @@ free_starfish(Display *display, starfishstruct * sp)
 		if (sp->colors != NULL) {
 			if (sp->ncolors && !sp->no_colors)
 				free_colors(display, sp->cmap, sp->colors, sp->ncolors);
-			(void) free((void *) sp->colors);
+			free(sp->colors);
 			sp->colors = (XColor *) NULL;
 		}
 		if (sp->cmap != None) {
@@ -169,11 +169,11 @@ free_starfish(Display *display, starfishstruct * sp)
 		sp->splines = (spline *) NULL;
 	}
 	if (sp->r != NULL) {
-		(void) free((void *) sp->r);
+		free(sp->r);
 		sp->r = (long *) NULL;
 	}
 	if (sp->prev != NULL) {
-		(void) free((void *) sp->prev);
+		free(sp->prev);
 		sp->prev = (XPoint *) NULL;
 	}
 }
@@ -256,7 +256,7 @@ make_starfish(ModeInfo * mi)
 	sp->splines = make_spline(sp->npoints);
 
 	if (sp->r != NULL)
-		(void) free((void *) sp->r);
+		free(sp->r);
 	if ((sp->r = (long *) malloc(sizeof (*sp->r) * sp->npoints)) == NULL) {
 		free_starfish(MI_DISPLAY(mi), sp);
 		return;
@@ -392,9 +392,9 @@ draw1_starfish(Display * display, Drawable drawable, GC gc, starfishstruct * sp)
 			XClearWindow(display, drawable);
 		XFillPolygon(display, drawable, gc, points, i + j,
 			     Complex, CoordModeOrigin);
-		(void) free((void *) points);
+		free(points);
 
-		(void) free((void *) sp->prev);
+		free(sp->prev);
 		sp->prev = (XPoint *) NULL;
 	}
 	if ((sp->prev = (XPoint *) malloc(sp->splines->n_points *
@@ -511,7 +511,7 @@ init_starfish(ModeInfo * mi)
 		if (sp->colors != NULL) {
 			if (sp->ncolors && !sp->no_colors)
 				free_colors(display, sp->cmap, sp->colors, sp->ncolors);
-			(void) free((void *) sp->colors);
+			free(sp->colors);
 			sp->colors = (XColor *) NULL;
 		}
 		sp->ncolors = MI_NCOLORS(mi);
@@ -573,7 +573,7 @@ init_starfish(ModeInfo * mi)
 	sp->winheight = MI_HEIGHT(mi);
 	MI_CLEARWINDOW(mi);
 	if (sp->prev != NULL) {
-		(void) free((void *) sp->prev);
+		free(sp->prev);
 		sp->prev = (XPoint *) NULL;
 	}
 	sp->stage = 0;
@@ -665,7 +665,7 @@ release_starfish(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_starfish(MI_DISPLAY(mi), &starfishes[screen]);
-		(void) free((void *) starfishes);
+		free(starfishes);
 		starfishes = (starfishstruct *) NULL;
 	}
 }
