@@ -196,7 +196,7 @@ free_swirl(Display *display, SWIRL_P swirl)
 		swirl->ximage = None;
 	}
 	if (swirl->knots != NULL) {
-		(void) free((void *) swirl->knots);
+		free(swirl->knots);
 		swirl->knots = (KNOT_P) NULL;
 	}
 }
@@ -286,7 +286,7 @@ initialise_image(Display * dpy, SWIRL_P swirl)
 	if ((swirl->ximage = XCreateImage(dpy, swirl->visual, image_depth, ZPixmap,
 				     0, (char *) image, swirl->width,
 				     swirl->height, pad, bytes_per_line)) == None) {
-		(void) free((void *) image);
+		free(image);
 		return False;
 	}
 	return True;
@@ -382,6 +382,7 @@ initialise_colours(COLOUR * colours, float saturate)
 static void
 set_black_and_white(SWIRL_P swirl, XColor * values)
 {
+	const int maxSize = 67; /* Saves DirectColor from crashing */
 	unsigned long white, black;
 
 	/* where is black and white? */
@@ -389,20 +390,26 @@ set_black_and_white(SWIRL_P swirl, XColor * values)
 	black = swirl->black;
 
 	/* set black and white up */
-	values[white].flags = DoRed | DoGreen | DoBlue;
-	values[white].pixel = white;
-	values[white].red = 0xFFFF;
-	values[white].green = 0xFFFF;
-	values[white].blue = 0xFFFF;
-	values[black].flags = DoRed | DoGreen | DoBlue;
-	values[black].pixel = black;
-	values[black].red = 0;
-	values[black].green = 0;
-	values[black].blue = 0;
+	if (white < maxSize) {  /* else DirectColor */
+		values[white].flags = DoRed | DoGreen | DoBlue;
+		values[white].pixel = white;
+		values[white].red = 0xFFFF;
+		values[white].green = 0xFFFF;
+		values[white].blue = 0xFFFF;
+	}
+	if (black < maxSize) {  /* else DirectColor */
+		values[black].flags = DoRed | DoGreen | DoBlue;
+		values[black].pixel = black;
+		values[black].red = 0;
+		values[black].green = 0;
+		values[black].blue = 0;
+	}
 
 	/* copy the colour specs from the original entries */
-	values[swirl->bg] = swirl->bgcol;
-	values[swirl->fg] = swirl->fgcol;
+	if (swirl->bg < maxSize) /* else DirectColor */
+		values[swirl->bg] = swirl->bgcol;
+	if (swirl->fg < maxSize) /* else DirectColor */
+		values[swirl->fg] = swirl->fgcol;
 }
 
 /****************************************************************/
@@ -865,7 +872,7 @@ create_knots(SWIRL_P swirl)
 
 	/* create array for knots */
 	if (swirl->knots)
-		(void) free((void *) swirl->knots);
+		free(swirl->knots);
 	if ((swirl->knots = (KNOT_P) calloc(swirl->n_knots,
 			sizeof (KNOT))) == NULL) {
 		return False;
@@ -1502,7 +1509,7 @@ release_swirl(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_swirl(MI_DISPLAY(mi), &swirls[screen]);
 		/* deallocate an array, one entry for each screen */
-		(void) free((void *) swirls);
+		free(swirls);
 		swirls = (SWIRL_P) NULL;
 	}
 }
