@@ -60,8 +60,8 @@ static const char sccsid[] = "@(#)t3d.c	5.0 2000/11/01 xlockmore";
 #include "color.h"
 #endif /* STANDALONE */
 
-#ifdef TIME_WITH_SYS_TIME /* for sco */
 #include <time.h>
+#ifdef TIME_WITH_SYS_TIME /* for sco */
 #include <sys/time.h>
 #endif
 
@@ -179,7 +179,7 @@ typedef struct {
    Bool        cycle_p, mono_p, no_colors;
    unsigned long blackpixel, whitepixel, fg, bg;
    int         direction;
-   struct tm *zeit;
+   struct tm  *zeit;
    kugeldat kugeln[100];
    int         color_offset;
    ModeInfo   *mi;
@@ -291,7 +291,7 @@ t3d_gettime (void)
 #else
   lt = NULL;
 #endif
-  zeit=localtime(&lt);
+  zeit = localtime((const time_t *) &lt);
 
   return (zeit->tm_sec+60*(zeit->tm_min+60*(zeit->tm_hour))
 	  + time1.tv_usec*1.0E-6);
@@ -605,7 +605,7 @@ free_t3d(Display *display, t3dstruct *t3dp)
 		if (t3dp->colors != NULL) {
 			if (t3dp->ncolors && !t3dp->no_colors)
 				free_colors(display, t3dp->cmap, t3dp->colors, t3dp->ncolors);
-			(void) free((void *) t3dp->colors);
+			free(t3dp->colors);
 			t3dp->colors = (XColor *) NULL;
 		}
 		if (t3dp->cmap != None) {
@@ -640,7 +640,7 @@ free_t3d(Display *display, t3dstruct *t3dp)
 	}
 #endif
 	if (t3dp->zeit != NULL) {
-		(void) free((void *) t3dp->zeit);
+		free(t3dp->zeit);
 		t3dp->zeit = (struct tm *) NULL;
 	}
 }
@@ -847,7 +847,7 @@ init_t3d(ModeInfo * mi)
 		if (t3dp->colors != NULL) {
 			if (t3dp->ncolors && !t3dp->no_colors)
 				free_colors(display, t3dp->cmap, t3dp->colors, t3dp->ncolors);
-			(void) free((void *) t3dp->colors);
+			free(t3dp->colors);
 			t3dp->colors = (XColor *) NULL;
 		}
 		t3dp->ncolors = MI_NCOLORS(mi);
@@ -950,7 +950,7 @@ release_t3d(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_t3d(MI_DISPLAY(mi), &t3ds[screen]);
-		(void) free((void *) t3ds);
+		free(t3ds);
 		t3ds = (t3dstruct *) NULL;
 	}
 }
