@@ -1617,7 +1617,7 @@ free_tetris(Display *display, trisstruct *tp)
     if (tp->colors != NULL) {
       if (tp->ncolors && !tp->no_colors)
         free_colors(display, tp->cmap, tp->colors, tp->ncolors);
-      (void) free((void *) tp->colors);
+      free(tp->colors);
       tp->colors = (XColor *) NULL;
     }
     if (tp->cmap != None) {
@@ -1634,7 +1634,7 @@ free_tetris(Display *display, trisstruct *tp)
     tp->graypix = None;
   }
   if (tp->field != NULL) {
-     (void) free((void *) tp->field);
+     free(tp->field);
      tp->field = (fieldstruct *) NULL;
   }
   free_images(tp);
@@ -1846,7 +1846,7 @@ checkLines(ModeInfo *mi)
     }
 
     if (lSet)
-      (void) free((void *) lSet);
+      free(lSet);
     return nset;
   }
 }
@@ -2020,7 +2020,7 @@ create_an_image(ModeInfo *mi, trisstruct *tp, int n)
 
   if ((tp->images[n] = XCreateImage(MI_DISPLAY(mi), MI_VISUAL(mi),
            1, XYBitmap, 0, (char *) data, tp->xs, tp->ys, 8, 0)) == None) {
-     (void) free((void *) data);
+     free(data);
      return False;
   }
   tp->images[n]->byte_order = MSBFirst;
@@ -2112,19 +2112,19 @@ release_tetris(ModeInfo * mi) {
 
     for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
        free_tetris(MI_DISPLAY(mi), &triss[screen]);
-    (void) free((void *) triss);
+    free(triss);
     triss = (trisstruct *) NULL;
     for (bonustype = 0; bonustype < 2; bonustype++) {
       if (polytris[bonustype].polyomino != NULL) {
         for (number = 0; number < max_ominoes[bonustype]; number++) {
           if (polytris[bonustype].polyomino[number].shape != NULL)
-            (void) free((void *) polytris[bonustype].polyomino[number].shape);
+            free(polytris[bonustype].polyomino[number].shape);
         }
-        (void) free((void *) polytris[bonustype].polyomino);
+        free(polytris[bonustype].polyomino);
         polytris[bonustype].polyomino = (Polyominoes *) NULL;
       }
       if (polytris[bonustype].mode.start != NULL) {
-        (void) free((void *) polytris[bonustype].mode.start);
+        free(polytris[bonustype].mode.start);
         polytris[bonustype].mode.start = (int *) NULL;
       }
     }
@@ -2309,7 +2309,7 @@ init_tetris(ModeInfo * mi) {
     tp->xb = (tp->width - tp->xs * tp->ncols) / 2;
     tp->yb = (tp->height - tp->ys * tp->nrows) / 2;
     if (tp->field != NULL)
-      (void) free((void *) tp->field);
+      free(tp->field);
     if ((tp->field = (fieldstruct *) malloc(tp->ncols * tp->nrows *
         sizeof (fieldstruct))) == NULL) {
       free_tetris(display, tp);
@@ -2330,7 +2330,7 @@ init_tetris(ModeInfo * mi) {
     if (tp->colors != NULL) {
       if (tp->ncolors && !tp->no_colors)
         free_colors(display, tp->cmap, tp->colors, tp->ncolors);
-      (void) free((void *) tp->colors);
+      free(tp->colors);
       tp->colors = (XColor *) NULL;
     }
     tp->ncolors = MI_NCOLORS(mi);
