@@ -229,7 +229,7 @@ free_tik_tak(Display *display, tik_takstruct *tiktak)
 		if (tiktak->colors != NULL) {
 			if (tiktak->ncolors && !tiktak->no_colors)
 				free_colors(display, tiktak->cmap, tiktak->colors, tiktak->ncolors);
-			(void) free((void *) tiktak->colors);
+			free(tiktak->colors);
 			tiktak->colors = (XColor *) NULL;
 		}
 		if (tiktak->cmap != None) {
@@ -249,11 +249,11 @@ free_tik_tak(Display *display, tik_takstruct *tiktak)
 
 			object0 = &tiktak->object[i];
 		 	if (object0->xy1 != NULL)
-				(void) free((void *) object0->xy1);
+				free(object0->xy1);
 			if (object0->xy != NULL)
-				(void) free((void *) object0->xy);
+				free(object0->xy);
 		}
-		(void) free((void *) tiktak->object);
+		free(tiktak->object);
 		tiktak->object = (tik_takobject *) NULL;
 	 }
 }
@@ -362,7 +362,7 @@ init_tik_tak(ModeInfo * mi)
 		if (tiktak->colors != NULL) {
 			if (tiktak->ncolors && !tiktak->no_colors)
 				free_colors(display, tiktak->cmap, tiktak->colors, tiktak->ncolors);
-			(void) free((void *) tiktak->colors);
+			free(tiktak->colors);
 			tiktak->colors = (XColor *) NULL;
 		}
 		tiktak->ncolors = MI_NCOLORS(mi);
@@ -472,7 +472,7 @@ init_tik_tak(ModeInfo * mi)
 							    2 ) );
 	     }
 	   if (object0->xy != NULL)
-			(void) free((void *) object0->xy);
+			free(object0->xy);
 	   if ((object0->xy = (XPoint *) malloc(sizeof( XPoint ) *
 				(2 * object0->num_point + 2))) == NULL) {
 			free_tik_tak(display, tiktak);
@@ -499,7 +499,7 @@ init_tik_tak(ModeInfo * mi)
 		        ( 1.0 / (float) ((LRAND() & 1) + 2 ) );
 		  }
 		if (object0->xy1 != NULL)
-			(void) free((void *) object0->xy1);
+			free(object0->xy1);
 		if ((object0->xy1 = (XPoint *) malloc(sizeof( XPoint ) *
 				(2 * object0->num_point1 + 2))) == NULL) {
 			free_tik_tak(display, tiktak);
@@ -605,7 +605,7 @@ release_tik_tak(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_tik_tak(MI_DISPLAY(mi), &tik_taks[screen]);
-		(void) free((void *) tik_taks);
+		free(tik_taks);
 		tik_taks = (tik_takstruct *) NULL;
 	}
 }
