@@ -516,7 +516,7 @@ free_state(circuitstruct * wp, int state)
 	while (wp->cellList[state]) {
 		current = wp->cellList[state];
 		wp->cellList[state] = wp->cellList[state]->next;
-		(void) free((void *) current);
+		free(current);
 	}
 	wp->ncells[state] = 0;
 }
@@ -580,7 +580,7 @@ draw_state(ModeInfo * mi, int state)
 		/* Finally get to draw */
 		XFillRectangles(MI_DISPLAY(mi), MI_WINDOW(mi), gc, rects, nrects);
 		/* Free up rects list and the appropriate part of the cellList */
-		(void) free((void *) rects);
+		free(rects);
 	} else {		/* TRI */
 		while (current) {
 			int         col, row, orient;
@@ -754,11 +754,11 @@ free_wire(Display *display, circuitstruct *wp)
 		wp->stippledGC = None;
 	}
 	if (wp->oldcells != NULL) {
-		(void) free((void *) wp->oldcells);
+		free(wp->oldcells);
 		wp->oldcells = (unsigned char *) NULL;
 	}
 	if (wp->newcells != NULL) {
-		(void) free((void *) wp->newcells);
+		free(wp->newcells);
 		wp->newcells = (unsigned char *) NULL;
 	}
 	free_list(wp);
@@ -772,7 +772,7 @@ release_wire(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_wire(MI_DISPLAY(mi), &circuits[screen]);
-		(void) free((void *) circuits);
+		free(circuits);
 		circuits = (circuitstruct *) NULL;
 	}
 }
@@ -942,7 +942,7 @@ init_wire(ModeInfo * mi)
 	MI_CLEARWINDOW(mi);
 
 	if (wp->oldcells != NULL) {
-		(void) free((void *) wp->oldcells);
+		free(wp->oldcells);
 		wp->oldcells = (unsigned char *) NULL;
 	}
 	if ((wp->oldcells = (unsigned char *) calloc(wp->bncols * wp->bnrows,
@@ -952,7 +952,7 @@ init_wire(ModeInfo * mi)
 	}
 
 	if (wp->newcells != NULL) {
-		(void) free((void *) wp->newcells);
+		free(wp->newcells);
 		wp->newcells = (unsigned char *) NULL;
 	}
 	if ((wp->newcells = (unsigned char *) calloc(wp->bncols * wp->bnrows,
