@@ -270,7 +270,7 @@ free_xcl(Display *display, xclstruct  *dp)
       
     for (plane = 0; plane < dp->planes; plane++) {
       if (dp->xseg[plane] != NULL) {
-        (void) free((void *) dp->xseg[plane]);
+        free(dp->xseg[plane]);
         dp->xseg[plane] = (XSegment *) NULL;
       }
       if (dp->xseg_old[plane] != NULL) {
@@ -294,7 +294,7 @@ void release_xcl(ModeInfo * mi)
     int screen;
     for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
       free_xcl(MI_DISPLAY(mi), &xcls[screen]);
-    (void) free((void *) xcls);
+    free(xcls);
     xcls = (xclstruct *) NULL;
   }
 }
