@@ -188,9 +188,9 @@ fixColormap(ModeInfo * mi, int ncolors, float saturation,
 			sizeof (unsigned char))) == NULL)) {
 		(void) fprintf(stderr, "could not get the %d colors\n", ncolors);
 		if (red != NULL)
-			(void) free((void *) red);
+			free(red);
 		if (green != NULL)
-			(void) free((void *) green);
+			free(green);
 		return;
 	}
 
@@ -216,7 +216,7 @@ fixColormap(ModeInfo * mi, int ncolors, float saturation,
 	}
 	/* else if (cmap) { (void) printf("cmap: this case is possible?\n");  } */
 	if (MI_PIXELS(mi))
-		(void) free((void *) MI_PIXELS(mi));
+		free(MI_PIXELS(mi));
 	if ((MI_PIXELS(mi) = (unsigned long *) calloc(ncolors,
 			sizeof (unsigned long))) == NULL) {
 		(void) fprintf(stderr, "could not get the %d colors\n", ncolors);
@@ -267,9 +267,9 @@ fixColormap(ModeInfo * mi, int ncolors, float saturation,
 		MI_PIXELS(mi)[i] = xcolor.pixel;
 		MI_NPIXELS(mi)++;
 	}
-	(void) free((void *) red);
-	(void) free((void *) green);
-	(void) free((void *) blue);
+	free(red);
+	free(green);
+	free(blue);
 	if (verbose)
 		(void) fprintf(stderr, "%d pixel%s allocated\n", MI_NPIXELS(mi),
 			       (MI_NPIXELS(mi) == 1) ? "" : "s");
@@ -427,7 +427,7 @@ free_colors(Display * dpy, Colormap cmap, XColor * colors, int ncolors)
 		for (i = 0; i < ncolors; i++)
 			pixels[i] = colors[i].pixel;
 		XFreeColors(dpy, cmap, pixels, ncolors, 0L);
-		(void) free((void *) pixels);
+		free(pixels);
 	}
 }
 
@@ -518,12 +518,12 @@ make_color_ramp(Display * dpy, Colormap cmap,
 		/* allocate_writable_colors() won't do here, because we need exactly this
 		   number of cells, or the color sequence we've chosen won't fit. */
 		if (!XAllocColorCells(dpy, cmap, False, 0, 0, pixels, *ncolorsP)) {
-			(void) free((void *) pixels);
+			free(pixels);
 			goto FAIL;
 		}
 		for (i = 0; i < *ncolorsP; i++)
 			colors[i].pixel = pixels[i];
-		(void) free((void *) pixels);
+		free(pixels);
 
 		XStoreColors(dpy, cmap, colors, *ncolorsP);
 	} else {
@@ -738,12 +738,12 @@ make_color_path(Display * dpy, Colormap cmap,
 		/* allocate_writable_colors() won't do here, because we need exactly this
 		   number of cells, or the color sequence we've chosen won't fit. */
 		if (!XAllocColorCells(dpy, cmap, False, 0, 0, pixels, *ncolorsP)) {
-			(void) free((void *) pixels);
+			free(pixels);
 			goto FAIL;
 		}
 		for (i = 0; i < *ncolorsP; i++)
 			colors[i].pixel = pixels[i];
-		(void) free((void *) pixels);
+		free(pixels);
 
 		XStoreColors(dpy, cmap, colors, *ncolorsP);
 	} else {
@@ -1003,7 +1003,7 @@ make_random_colormap(ModeInfo * mi, Colormap cmap,
 		if (ncolors > 0)
 			for (i = 0; i < ncolors; i++)
 				colors[i].pixel = pixels[i];
-		(void) free((void *) pixels);
+		free(pixels);
 		if (ncolors > 0)
 			XStoreColors(MI_DISPLAY(mi), cmap, colors, ncolors);
 	} else {
@@ -1055,7 +1055,7 @@ rotate_colors(Display * dpy, Colormap cmap,
 	XStoreColors(dpy, cmap, colors2, ncolors);
 	XFlush(dpy);
 	(void) memcpy((char *) colors, colors2, sizeof (*colors) * ncolors);
-	(void) free((void *) colors2);
+	free(colors2);
 }
 
 /* xscreensaver, Copyright (c) 1992, 1997 Jamie Zawinski <jwz@jwz.org>
