@@ -29,8 +29,9 @@ static const char sccsid[] = "@(#)erase.c	5.03 2001/10/18 xlockmore";
 #undef countof
 #define countof(x) (sizeof(x)/sizeof(*(x)))
 
-extern int  erasedelay, erasemode, erasetime;
-extern int erasemodefromname(char *name);
+extern int erasedelay, erasetime;
+extern void erasemodefromname(char *name, Bool verbose);
+static int advanceErase();
 
 typedef void (*Eraser) (Display * dpy, Window window, GC gc,
 			int width, int height, int delay, int granularity);
@@ -85,7 +86,7 @@ random_lines(Display * dpy, Window window, GC gc,
 #undef LOOPVAR
 
 	}
-	(void) free((void *) lines);
+	free(lines);
 #include "erase_debug.h"
 }
 #undef ERASEMODE
@@ -133,7 +134,7 @@ random_squares(Display * dpy, Window window, GC gc,
 #undef LOOPVAR
 
 	}
-	(void) free((void *) squares);
+	free(squares);
 #include "erase_debug.h"
 }
 #undef ERASEMODE
@@ -181,7 +182,7 @@ venetian(Display * dpy, Window window, GC gc,
 #undef LOOPVAR
 
 	}
-	(void) free((void *) lines);
+	free(lines);
 #include "erase_debug.h"
 }
 #undef ERASEMODE
@@ -235,7 +236,7 @@ triple_wipe(Display * dpy, Window window, GC gc,
 #undef LOOPVAR
 
 	}
-	(void) free((void *) lines);
+	free(lines);
 #include "erase_debug.h"
 }
 #undef ERASEMODE
@@ -288,7 +289,7 @@ quad_wipe(Display * dpy, Window window, GC gc,
 #undef LOOPVAR
 
 	}
-	(void) free((void *) lines);
+	free(lines);
 #include "erase_debug.h"
 }
 #undef ERASEMODE
@@ -529,7 +530,7 @@ fizzle (Display *dpy, Window window, GC gc,
 # undef SKEWX
 # undef SKEWY
 
-	(void) free((void *) skews);
+	free(skews);
 
 # undef BX
 # undef BY
@@ -708,7 +709,6 @@ losira (Display *dpy, Window window, GC gc, int width, int height, int delay,
 #define ERASEMODE "losira"
   XGCValues gcv;
   XWindowAttributes wa;
-  XColor white;
   GC white_gc; 
   XArc arc[2][8];
   double xx[8], yy[8], dx[8], dy[8];
@@ -720,10 +720,7 @@ losira (Display *dpy, Window window, GC gc, int width, int height, int delay,
 #include "erase_init.h"
 
   XGetWindowAttributes(dpy, window, &wa);
-  white.flags = DoRed|DoGreen|DoBlue;
-  white.red = white.green = white.blue = 65535;
-  XAllocColor(dpy, wa.colormap, &white);
-  gcv.foreground = white.pixel;
+  gcv.foreground = XWhitePixelOfScreen(wa.screen);
   white_gc = XCreateGC(dpy, window, GCForeground, &gcv);
 
   XSetGraphicsExposures(dpy , gc , False );
@@ -862,7 +859,6 @@ losira (Display *dpy, Window window, GC gc, int width, int height, int delay,
 #include "erase.h"
 #undef LOOPVAR
      }
-  XFreeColors(dpy, wa.colormap, &white.pixel, 1, 0);
   XFreeGC(dpy, white_gc);
   gcv.line_width = 1;  
   XChangeGC(dpy, gc, GCLineWidth, &gcv);
@@ -900,16 +896,16 @@ static struct eraser_names {
 		squaretate, (char *) "squaretate"
 	},
 	{
-		fizzle , (char *) "fizzle"
+		fizzle, (char *) "fizzle"
 	},
 	{
-		spiral , (char *) "spiral"
+		spiral, (char *) "spiral"
 	},
 	{
-		slide_lines , (char *) "slide_lines"
+		slide_lines, (char *) "slide_lines"
 	},
 	{
-		losira , (char *) "losira"
+		losira, (char *) "losira"
 	},
 	{
 		no_fade, (char *) "no_fade"
@@ -918,18 +914,24 @@ static struct eraser_names {
 
 
 static void
-erase_window(ModeInfo * mi, GC erase_gc, unsigned long pixel, int mode,
-	     int delay)
+erase_window(ModeInfo * mi, GC erase_gc, unsigned long pixel, int delay)
 {
-	int         granularity = 1;
+	int         granularity = 1, mode;
 
 	XSetForeground(MI_DISPLAY(mi), erase_gc, pixel);
 	if (MI_IS_DRAWN(mi) && delay > 0) {
+#if 0
 		if (mode < 0 || mode >= (int) countof(erasers))
 			mode = NRAND(countof(erasers));
+#else
+		mode = advanceErase();
+	        if (MI_IS_VERBOSE(mi))
+			(void) fprintf(stdout, "erasemode %d: %s\n", mode,
+				erasers[mode].name);
+#endif
 		(*(erasers[mode].mode)) (MI_DISPLAY(mi), MI_WINDOW(mi),
-				       erase_gc, MI_WIDTH(mi), MI_HEIGHT(mi),
-					 delay, granularity);
+			erase_gc, MI_WIDTH(mi), MI_HEIGHT(mi),
+			delay, granularity);
 		MI_IS_DRAWN(mi) = False;
 	}
 	XFillRectangle(MI_DISPLAY(mi), MI_WINDOW(mi), erase_gc, 0, 0,
@@ -939,11 +941,12 @@ erase_window(ModeInfo * mi, GC erase_gc, unsigned long pixel, int mode,
 void
 erase_full_window(ModeInfo * mi, GC erase_gc, unsigned long pixel)
 {
-	erase_window(mi, erase_gc, pixel, erasemode, erasedelay);
+	erase_window(mi, erase_gc, pixel, erasedelay);
 }
 
+#if 0
 int
-erasemodefromname(char *name)
+erasemodefromname(char *name, Bool verbose)
 {
 	int         a;
 	char       *s1, *s2;
@@ -966,5 +969,192 @@ erasemodefromname(char *name)
 			eraseMode = a;
 		}
 	}
+	if (verbose)
+		(void) fprintf(stderr, "Using erase mode %s\n", name);
 	return (eraseMode);
 }
+#else
+
+static int  currentEraseMode = -1;
+/* static int  previousEraseMode = -1; */
+static int *eraseModes;
+static int  nEraseModes;
+#if DEBUG
+static Bool sequential = True;
+#else
+static Bool sequential = False;
+#endif
+
+static int
+pickMode(void)
+{
+	static int *eraseModeIndexes = (int *) NULL;
+	static int  eraseModeCount = 0;
+	static int  lastEraseMode = -1, lastIndex = -1;
+	int         eraseMode, i;
+
+	if (eraseModeIndexes == NULL) {
+		if ((eraseModeIndexes = (int *) calloc(nEraseModes,
+				sizeof (int))) == NULL) {
+			if (sequential)
+				return eraseModes[0];
+			else
+				return eraseModes[NRAND(nEraseModes)];
+		}
+	}
+	if (eraseModeCount == 0) {
+		for (i = 0; i < nEraseModes; i++) {
+			eraseModeIndexes[i] = eraseModes[i];
+		}
+		eraseModeCount = nEraseModes;
+	}
+	if (eraseModeCount == 1) {
+		/* only one left, let's use that one */
+		lastIndex = -1;
+		return (lastEraseMode = eraseModeIndexes[--eraseModeCount]);
+	} else {
+		/* pick a random slot in the list, check for last */
+		if (sequential) {
+			lastIndex = i = (lastIndex + 1) % nEraseModes;
+		} else
+			while (eraseModeIndexes[i = NRAND(eraseModeCount)] == lastEraseMode);
+	}
+
+	eraseMode = eraseModeIndexes[i];	/* copy out chosen eraseMode */
+	/* move eraseMode at end of list to slot vacated by chosen eraseMode, dec count */
+	eraseModeIndexes[i] = eraseModeIndexes[--eraseModeCount];
+	return (lastEraseMode = eraseMode);	/* remember last eraseMode picked */
+}
+
+static char *
+strpmtok(int *sign, char *str)
+{
+	static int  nextsign = 0;
+	static char *loc;
+	char       *p, *r;
+
+	if (str)
+		loc = str;
+	if (nextsign) {
+		*sign = nextsign;
+		nextsign = 0;
+	}
+	p = loc - 1;
+	for (;;) {
+		switch (*++p) {
+			case '+':
+				*sign = 1;
+				continue;
+			case '-':
+				*sign = -1;
+				continue;
+			case ' ':
+			case ',':
+			case '\t':
+			case '\n':
+				continue;
+			case 0:
+				loc = p;
+				return (char *) NULL;
+		}
+		break;
+	}
+	r = p;
+
+	for (;;) {
+		switch (*++p) {
+			case '+':
+				nextsign = 1;
+				break;
+			case '-':
+				nextsign = -1;
+				break;
+			case ' ':
+			case ',':
+			case '\t':
+			case '\n':
+			case 0:
+				break;
+			default:
+				continue;
+		}
+		break;
+	}
+	if (*p) {
+		*p = 0;
+		loc = p + 1;
+	} else
+		loc = p;
+
+	return r;
+}
+
+static Bool
+parseEraseModeList(char * eraseModeList, Bool verbose)
+{
+	int         i, sign = 1;
+	char       *p;
+
+	if ((eraseModes = (int *) calloc(countof(erasers), sizeof (int))) == NULL) {
+			return False;
+	}
+	p = strpmtok(&sign, (eraseModeList) ? eraseModeList : (char *) "");
+
+	while (p) {
+		if (!strcmp(p, "all")) {
+			for (i = 0; i < (int) countof(erasers); i++) {
+				eraseModes[i] = (sign > 0);
+			}
+		} else {
+			for (i = 0; i < (int) countof(erasers); i++)
+				if (!strcmp(p, erasers[i].name))
+					break;
+			if (i < (int) countof(erasers))
+				eraseModes[i] = (sign > 0);
+			else
+				(void) fprintf(stderr, "unrecognized eraseMode \"%s\"\n", p);
+		}
+		p = strpmtok(&sign, (char *) NULL);
+	}
+
+	nEraseModes = 0;
+	for (i = 0; i < (int) countof(erasers); i++)
+		if (eraseModes[i])
+			eraseModes[nEraseModes++] = i;
+	if (!nEraseModes) {		/* empty list */
+		for (i = 0; i < (int) countof(erasers); i++) {
+			eraseModes[i] = i;
+		}
+		nEraseModes = (int) countof(erasers);
+	}
+	if (verbose) {
+		(void) fprintf(stderr, "%d eraseMode%s: ", nEraseModes, ((nEraseModes == 1) ? "" : "s"));
+		for (i = 0; i < nEraseModes; i++)
+			(void) fprintf(stderr, "%s ", erasers[eraseModes[i]].name);
+		(void) fprintf(stderr, "\n");
+	}
+	return True;
+}
+
+void
+erasemodefromname(char *name, Bool verbose)
+{
+	if (currentEraseMode < 0) {
+		if (!parseEraseModeList(name, verbose))
+			return;
+		currentEraseMode = pickMode();
+	}
+}
+
+
+static int
+advanceErase()
+{
+	if (currentEraseMode < 0)
+		return 0;
+
+	/* previousEraseMode = currentEraseMode; */
+	currentEraseMode = pickMode();
+	return currentEraseMode;
+}
+#endif
