@@ -230,7 +230,7 @@ sel_image(struct dirent *name)
 		}
 		if ( strlen( filename_tmp ) != 0 ) {
 			if (numfrag > 0 && frags[numfrag] != NULL)
-				(void) free((void *) frags[numfrag]);
+				free(frags[numfrag]);
 			if ((frags[numfrag] = (char *) malloc(strlen(filename_tmp) +
 					1)) == NULL) {
 				numfrag--;
@@ -244,7 +244,7 @@ sel_image(struct dirent *name)
 #ifdef VMS
 	i = 0;
 	ip = index_dir(name_tmp, frags[i]);
-	(void) free((void *) frags[i]);
+	free(frags[i]);
 	if ( not_first_star ) {
 		if ( ip != 1 )
 			goto FAIL;
@@ -260,7 +260,7 @@ sel_image(struct dirent *name)
 		for (i = 0; i <= numfrag; ++i) {
 #endif
 			ip = index_dir(name_tmp, frags[i]);
-			(void) free((void *) frags[i]);
+			free(frags[i]);
 			if (ip == 0) {
 				goto FAIL;
 			}
@@ -276,7 +276,7 @@ FAIL:
 		int         j;
 
 		for (j = i + 1; j <= numfrag; ++j)
-			(void) free((void *) frags[j]);
+			free(frags[j]);
 		return (0);
 	}
 }
@@ -370,15 +370,15 @@ getRandomFile(char *randomfile, char *randomfile_local)
 
 		for (i = 0; i < num_list; i++) {
 			if (image_list[i] != NULL)
-				(void) free((void *) image_list[i]);
+				free(image_list[i]);
 		}
-		(void) free((void *) image_list);
+		free(image_list);
 		image_list = (struct dirent **) NULL;
 	}
 	if ((images_list = (struct dirent ***) malloc(sizeof (struct dirent **))) != NULL) {
 		num_list = scan_dir(directory_r, images_list, sel_image, NULL);
 		image_list = *images_list;
-		(void) free((void *) images_list);
+		free(images_list);
 		if (num_list > 0) {
 			randomFileFromList(directory_r, image_list, num_list,
 				randomfile_local);
@@ -451,7 +451,7 @@ getImage(ModeInfo * mi, XImage ** logo,
 	*graphics_format = 0;
 
 	if (bitmap_local != NULL) {
-		(void) free((void *) bitmap_local);
+		free(bitmap_local);
 		bitmap_local = (char *) NULL;
 	}
 	if (MI_BITMAP(mi) && strlen(MI_BITMAP(mi))) {
@@ -590,7 +590,7 @@ destroyImage(XImage ** logo, int *graphics_format)
 			break;
 		case IS_XBMFILE:
 			if (blogo.data) {
-				(void) free((void *) blogo.data);
+				free(blogo.data);
 				blogo.data = (char *) NULL;
 			}
 			break;
@@ -648,7 +648,7 @@ getPixmap(ModeInfo * mi, Drawable drawable,
 	static char *bitmap_local = (char *) NULL;
 
 	if (bitmap_local) {
-		(void) free((void *) bitmap_local);
+		free(bitmap_local);
 		bitmap_local = (char *) NULL;
 	}
 	if (MI_BITMAP(mi) && strlen(MI_BITMAP(mi))) {
@@ -677,7 +677,7 @@ getModeFont(char *infont)
 	static char *localfont = (char *) NULL;
 
 	if (localfont != NULL) {
-		(void) free((void *) localfont);
+		free(localfont);
 		localfont = (char *) NULL;
 	}
 	if (infont && strlen(infont)) {
@@ -699,7 +699,7 @@ getModeFont(char *infont)
 		(void) fprintf(stderr,
 		       "could not read file \"%s\"\n", localfont);
 		if (localfont) {
-			(void) free((void *) localfont);
+			free(localfont);
 			localfont = (char *) NULL;
 		}
 	}
