@@ -52,6 +52,12 @@ LockStruct  LockProcs[] =
 	 25000, 4, 100, 6000, 64, 1.0, (char *) "",
 	 (char *) "Shows moving sharks/whales/dolphin", 0, NULL},
 #endif
+#ifdef MODE_atunnels
+	{(char *) "atunnels", init_atunnels, draw_atunnels, release_atunnels,
+	 refresh_atunnels, change_atunnels, (ModeHook *) NULL, &atunnels_opts,
+	 25000, 1, 1, 400, 64, 1.0, (char *) "",
+	 (char *) "Shows an OpenGL advanced tunnel screensaver", 0, NULL},
+#endif
 #ifdef MODE_ball
 	{(char *) "ball", init_ball, draw_ball, release_ball,
 	 refresh_ball, init_ball, (ModeHook *) NULL, &ball_opts,
@@ -118,6 +124,12 @@ LockStruct  LockProcs[] =
 	 80000, 1, 1, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows the Impossible Cage, an Escher-like GL scene", 0, NULL},
 #endif
+#ifdef MODE_cartoon
+	{"cartoon", init_cartoon, draw_cartoon, release_cartoon,
+	 NULL, init_cartoon, NULL, &cartoon_opts,
+	 10000, 1, 1, 1, 64, 1.0, "",
+	 "Shows bouncing cartoons", 0, NULL},
+#endif
 #ifdef MODE_clock
 	{(char *) "clock", init_clock, draw_clock, release_clock,
 	 refresh_clock, init_clock, (ModeHook *) NULL, &clock_opts,
@@ -211,7 +223,7 @@ LockStruct  LockProcs[] =
 #ifdef MODE_fire
 	{(char *) "fire", init_fire, draw_fire, release_fire,
 	 draw_fire, change_fire, (ModeHook *) NULL, &fire_opts,
-	 10000, 800, 1, 1, 64, 1.0, (char *) "",
+	 10000, 800, 1, 400, 64, 1.0, (char *) "",
 	 (char *) "Shows a 3D fire-like image", 0, NULL},
 #endif
 #ifdef MODE_flag
@@ -322,6 +334,12 @@ LockStruct  LockProcs[] =
 	 10000, 1000, 20, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows the Julia set", 0, NULL},
 #endif
+#ifdef MODE_kaleid2
+	{"kaleid2", init_kaleid2, draw_kaleid2, release_kaleid2,
+	     refresh_kaleid2, init_kaleid2, NULL, &kaleid2_opts,
+	     20000, 1, 700, 1, 64, 1.0, "",
+	     "Shows a kaleidoscope", 0, NULL},
+#endif
 #ifdef MODE_kaleid
 	{(char *) "kaleid", init_kaleid, draw_kaleid, release_kaleid,
 	 refresh_kaleid, init_kaleid, (ModeHook *) NULL, &kaleid_opts,
@@ -462,7 +480,7 @@ LockStruct  LockProcs[] =
 #endif
 #ifdef MODE_pacman
 	{(char *) "pacman", init_pacman, draw_pacman, release_pacman,
-	 refresh_pacman, init_pacman, (ModeHook *) NULL, &pacman_opts,
+	 refresh_pacman, change_pacman, (ModeHook *) NULL, &pacman_opts,
 	 20000, 10, 1, 0, 64, 1.0, (char *) "",
 	 (char *) "Shows Pacman(tm)", 0, NULL},
 #endif
@@ -478,6 +496,12 @@ LockStruct  LockProcs[] =
 	 10000, -500, 400, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows various GCD Flowers", 0, NULL},
 #endif
+#ifdef MODE_petri
+	{(char *) "petri", init_petri, draw_petri, release_petri,
+	 refresh_petri, init_petri, (ModeHook *) NULL, &petri_opts,
+	 10000, 1, 1, 4, 8, 1.0, (char *) "",
+	 (char *) "Shows a mold simulation in a petri dish", 0, NULL},
+#endif
 #ifdef MODE_pipes
 	{(char *) "pipes", init_pipes, draw_pipes, release_pipes,
 #if defined( MESA ) && defined( SLOW )
@@ -642,7 +666,7 @@ LockStruct  LockProcs[] =
 #ifdef MODE_swarm
 	{(char *) "swarm", init_swarm, draw_swarm, release_swarm,
 	 refresh_swarm, init_swarm, (ModeHook *) NULL, &swarm_opts,
-	 15000, -100, -100, 1, 64, 1.0, (char *) "",
+	 15000, -100, 1, -10, 64, 1.0, (char *) "",
 	 (char *) "Shows a swarm of bees following a wasp", 0, NULL},
 #endif
 #ifdef MODE_swirl
@@ -895,8 +919,8 @@ ExpandPath(char *path)
 
 #define nextone (void) fprintf(stderr, "LoadModule: %s: %s\n", cpath, dlerror()); \
 (void) dlclose(mp); \
-(void) free((void *) newstack->lock); \
-(void) free((void *) newstack); \
+free(newstack->lock); \
+free(newstack); \
 continue
 
 void
@@ -1047,7 +1071,7 @@ LoadModules(char *path)
 
 		(void) closedir(dp);
 	}			/* for (thisp = ... */
-	(void) free((void *) p);
+	free(p);
 
 	if (count > 0) {
 		int         i;
@@ -1069,14 +1093,14 @@ LoadModules(char *path)
 			locks[i] = head->lock;
 			discard = head;
 			head = head->next;
-			(void) free((void *) discard);
+			free(discard);
 		}
 		(void) qsort((void *) locks, count, sizeof (LockStruct *), lock_compare);
 		for (i = 0; i < count; i++) {
 			(void) memcpy(&LockProcs[i], locks[i], sizeof (LockStruct));
-			(void) free((void *) locks[i]);
+			free(locks[i]);
 		}
-		(void) free((void *) locks);
+		free(locks);
 	}
 	numprocs = count;
 }
@@ -1090,10 +1114,10 @@ UnloadModules()
 		for (i = 0; i < numprocs; i++)
 			(void) dlclose(LoadedModules[i]);
 
-		(void) free((void *) LoadedModules);
+		free(LoadedModules);
 	}
 	if (LockProcs != NULL)
-		(void) free((void *) LockProcs);
+		free(LockProcs);
 }
 
 #endif /* #ifndef USE_MODULES ... #else */
@@ -1129,7 +1153,7 @@ set_window_title(ModeInfo * mi)
 		XSetWMName(MI_DISPLAY(mi), MI_WINDOW(mi), &prop);
 		XFree((caddr_t) prop.value);
 	}
-	(void) free((void *) buf);
+	free(buf);
 	if (MI_IS_ICONIC(mi) && description) {
 		modeDescription(mi);
 	}
@@ -1299,5 +1323,3 @@ call_change_hook(LockStruct * ls, ModeInfo * mi)
 		ls->change_hook(mi);
 	}
 }
-
-/* -------------------------------------------------------------------- */
