@@ -53,7 +53,7 @@ extern Bool grabmouse;
 extern Bool nolock;
 extern char *cpasswd;
 
-#if defined( __CYGWIN__ )
+#ifdef __CYGWIN__
 #include <crypt.h>
 #endif
 
@@ -319,7 +319,7 @@ PAM_conv(int num_msg,
 				break;
 			default:
 				/* Must be an error of some sort... */
-				(void) free((void *) reply);
+				free(reply);
 				return PAM_CONV_ERR;
 		}
 	}
@@ -409,6 +409,9 @@ my_passwd_entry(void)
 	if (!pw)
 		return (pw);
 #ifdef HAVE_SHADOW
+/*- 
+ * PURIFY on Solaris 2 reports a 1024 byte memory leak on the following line
+ * if using NIS compatibility mode, and is internal to libc.so */
 	if ((spw = getspnam(pw->pw_name)) != NULL) {
 		char       *tmp;	/* swap */
 
@@ -443,7 +446,7 @@ checkDynamic()
 		(void) sprintf(buf,
 			     "%s: could not get user shell.\n", ProgramName);
 		error(buf);
-		(void) free((void *) buf);	/* Should never get here */
+		free(buf);	/* Should never get here */
 	}
 	return (!(strcmp(pw->pw_shell, SAFELOG_SWCHECK) &&
 		  strcmp(pw->pw_shell, SAFELOG_IDENT)));
@@ -488,7 +491,7 @@ getUserName(void)
 		(void) sprintf(buf,
 			       "%s: could not get user password (fork failed)\n", ProgramName);
 		error(buf);
-		(void) free((void *) buf);	/* Should never get here */
+		free(buf);	/* Should never get here */
 	}
 	(void) close(pipefd[1]);
 
@@ -502,7 +505,7 @@ getUserName(void)
 		(void) sprintf(buf,
 		 "%s: could not get user name (read failed)\n", ProgramName);
 		error(buf);
-		(void) free((void *) buf);	/* Should never get here */
+		free(buf);	/* Should never get here */
 	}
 	user[total] = 0;
 
@@ -511,7 +514,7 @@ getUserName(void)
 		(void) sprintf(buf,
 			       "%s: could not get user name (lookups failed)\n", ProgramName);
 		error(buf);
-		(void) free((void *) buf);	/* Should never get here */
+		free(buf);	/* Should never get here */
 	}
 #else /* !HP_PASSWDETC */
 #ifdef OSF1_ENH_SEC
@@ -524,7 +527,7 @@ getUserName(void)
 		(void) sprintf(buf,
 			       "%s: could not get user name.\n", ProgramName);
 		error(buf);
-		(void) free((void *) buf);	/* Should never get here */
+		free(buf);	/* Should never get here */
 	}
 	(void) strcpy(user, pw->ufld.fd_name);
 #else /* !OSF1_ENH_SEC */
@@ -538,7 +541,7 @@ getUserName(void)
 		(void) sprintf(buf,
 			       "%s: could not get user name.\n", ProgramName);
 		error(buf);
-		(void) free((void *) buf);	/* Should never get here */
+		free(buf);	/* Should never get here */
 	}
 	(void) strcpy(user, pw->pw_name);
 
@@ -601,7 +604,7 @@ gpass(void)
 				(void) sprintf(buf,
 					  "%s: Who are you?\n", ProgramName);
 				error(buf);
-				(void) free((void *) buf);	/* Should never get here */
+				free(buf);	/* Should never get here */
 			}
 			home = p->pw_dir;
 		}
@@ -728,7 +731,7 @@ getCryptedUserPasswd(void)
 		(void) sprintf(buf,
 			       "%s: could not get user password (fork failed)\n", ProgramName);
 		error(buf);
-		(void) free((void *) buf);	/* Should never get here */
+		free(buf);	/* Should never get here */
 	}
 	(void) close(pipefd[1]);
 
@@ -742,7 +745,7 @@ getCryptedUserPasswd(void)
 		(void) sprintf(buf,
 			       "%s: could not get user password (read failed)\n", ProgramName);
 		error(buf);
-		(void) free((void *) buf);	/* Should never get here */
+		free(buf);	/* Should never get here */
 	}
 	user[total] = 0;
 
@@ -751,7 +754,7 @@ getCryptedUserPasswd(void)
 		(void) sprintf(buf,
 			       "%s: could not get user password (lookups failed)\n", ProgramName);
 		error(buf);
-		(void) free((void *) buf);	/* Should never get here */
+		free(buf);	/* Should never get here */
 	}
 #else /* !HP_PASSWDETC */
 #ifdef OSF1_ENH_SEC
@@ -764,7 +767,7 @@ getCryptedUserPasswd(void)
 		(void) sprintf(buf,
 		"%s: could not get encrypted user password.\n", ProgramName);
 		error(buf);
-		(void) free((void *) buf);	/* Should never get here */
+		free(buf);	/* Should never get here */
 	}
 	(void) strcpy(userpass, pw->ufld.fd_encrypt);
 	/* also save encryption algorithm associated with encrypted password */
@@ -779,7 +782,7 @@ getCryptedUserPasswd(void)
 		(void) sprintf(buf,
 		"%s: could not get encrypted user password.\n", ProgramName);
 		error(buf);
-		(void) free((void *) buf);	/* Should never get here */
+		free(buf);	/* Should never get here */
 	}
 	/*if ((pw = (struct passwd *) getpwuid(getuid())) == NULL) */
 	/* Check if there is any chance of unlocking the display later...  */
@@ -871,7 +874,7 @@ getCryptedRootPasswd(void)
 		(void) sprintf(buf,
 			       "%s: could not get root password (fork failed)\n", ProgramName);
 		error(buf);
-		(void) free((void *) buf);	/* Should never get here */
+		free(buf);	/* Should never get here */
 	}
 	(void) close(pipefd[1]);
 
@@ -885,7 +888,7 @@ getCryptedRootPasswd(void)
 		(void) sprintf(buf,
 			       "%s: could not get root password (read failed)\n", ProgramName);
 		error(buf);
-		(void) free((void *) buf);	/* Should never get here */
+		free(buf);	/* Should never get here */
 	}
 	rootpass[total] = 0;
 
@@ -894,7 +897,7 @@ getCryptedRootPasswd(void)
 		(void) sprintf(buf,
 			       "%s: could not get root password (lookups failed)\n", ProgramName);
 		error(buf);
-		(void) free((void *) buf);	/* Should never get here */
+		free(buf);	/* Should never get here */
 	}
 #else /* !HP_PASSWDETC */
 #ifdef OSF1_ENH_SEC
@@ -906,7 +909,7 @@ getCryptedRootPasswd(void)
 		(void) sprintf(buf,
 		"%s: could not get encrypted root password.\n", ProgramName);
 		error(buf);
-		(void) free((void *) buf);	/* Should never get here */
+		free(buf);	/* Should never get here */
 	}
 	(void) strcpy(rootpass, pw->ufld.fd_encrypt);
 	/* also save encryption algorithm associated with encrypted password */
@@ -927,9 +930,12 @@ getCryptedRootPasswd(void)
 			(void) sprintf(buf,
 				       "%s: could not get encrypted root password.\n", ProgramName);
 			error(buf);
-			(void) free((void *) buf);	/* Should never get here */
+			free(buf);	/* Should never get here */
 		}
 #ifdef HAVE_SHADOW
+/*-
+ * PURIFY on Solaris 2 reports a 1024 byte memory leak on the following line
+ * if using NIS compatibility mode, and is internal to libc.so */
 	if ((spw = getspnam(pw->pw_name)) != NULL) {
 		char       *tmp;	/* swap */
 
@@ -972,6 +978,9 @@ checkUser(char *buffer)
 		(void) strcpy(userpass, "*");
 	else {
 #ifdef HAVE_SHADOW
+/*- 
+ * PURIFY on Solaris 2 reports a 1024 byte memory leak on the following line
+ * if using NIS compatibility mode, and is internal to libc.so */
 	if ((spw = getspnam(pw->pw_name)) != NULL) {
 		char       *tmp;	/* swap */
 
@@ -1065,13 +1074,11 @@ checkPasswd(char *buffer)
 }
 #ifdef BAD_PAM
 	ruid = getuid();  /* the real user we are running as */
+	(void) seteuid(0); /* temporarily go to root so that pam can get shadow password */
 #endif
 	PAM_password = buffer;
 	pam_error = pam_start("xlock", user, &PAM_conversation, &pamh);
 	PAM_BAIL;
-#ifdef BAD_PAM
-	(void) seteuid(0); /* temporarily go to root so that pam can get shadow password */
-#endif
 	pam_error = pam_authenticate(pamh, 0);
 	if (pam_error != PAM_SUCCESS) {
                 if (!allowroot) {
@@ -1257,7 +1264,7 @@ checkPasswd(char *buffer)
 			done = False;
 	}
 #if 0
-	(void) printf("buffer=%s, encrypt=%s, userpass=%s\n", buffer,
+	(void) printf("buffer=%s, encrypt=%s, userpass=%s,\n", buffer,
 		      (char *) crypt(buffer, userpass), userpass);
 #endif
 	if (!done && allowroot &&
@@ -1268,10 +1275,11 @@ checkPasswd(char *buffer)
 #endif
 	) {
 		done = True;	
-		if (!rootpass || !*buffer)
+		if (!(rootpass && *buffer))
 			/*
 			 * root has no password, don't let him in...
 			 */
+
 			done = False;
 #if ( HAVE_SYSLOG_H && defined( USE_SYSLOG ))
 		else
@@ -1334,7 +1342,7 @@ initDCE(void)
 				(void) sprintf(buf,
 					 "%s: out of memory\n", ProgramName);
 				error(buf);
-				(void) free((void *) buf);	/* Should never get here */
+				free(buf);	/* Should never get here */
 			default:
 				(void) fprintf(stderr,
 					       "%s: sec_login_setup_identity() returned status %d\n",
@@ -1348,7 +1356,7 @@ initDCE(void)
 			(void) sprintf(buf,
 			   "%s: could not get user password\n", ProgramName);
 			error(buf);
-			(void) free((void *) buf);	/* Should never get here */
+			free(buf);	/* Should never get here */
 		}
 		usernet = 0;
 		(void) strcpy(userpass, pwd->pw_passwd);
@@ -1381,7 +1389,7 @@ initDCE(void)
 					(void) sprintf(buf,
 					 "%s: out of memory\n", ProgramName);
 					error(buf);
-					(void) free((void *) buf);	/* Should never get here */
+					free(buf);	/* Should never get here */
 				default:
 					(void) fprintf(stderr,
 						       "%s: sec_login_setup_identity() returned status %d\n",
@@ -1522,7 +1530,7 @@ check_dce_net_passwd(char *usr, char *pass)
 			       error_string(error_status));
 	}
 	/* done with the copy of the password */
-	(void) free((void *) passcpy);
+	free(passcpy);
 
 	/* Refresh the context if we already have one */
 	if (current_context) {
@@ -1550,7 +1558,7 @@ check_dce_net_passwd(char *usr, char *pass)
 			}
 		}
 		/* done with the copy of the password */
-		(void) free((void *) passcpy);
+		free(passcpy);
 	}
 	/* make sure that the authentication service is not an imposter */
 	if (valid) {
@@ -1870,6 +1878,9 @@ set_multiple(int uid)
 			if (pw->pw_uid != uid)
 				continue;
 #ifdef HAVE_SHADOW
+/*- 
+ * PURIFY on Solaris 2 reports a 1024 byte memory leak on the following line
+ * if using NIS compatibility mode, and is internal to libc.so */
 			if ((spw = getspnam(pw->pw_name)) != NULL) {
 				char       *tmp;	/* swap */
 
