@@ -171,13 +171,17 @@ static int  descr();
 # define DEF_VALID	"Validation ..."
 # define DEF_INVALID	"Mot de passe Invalide."
 # define DEF_INFO	"Entrez le mot de passe ou choisissez l'icone pour verrouiller."
+# define DEF_COUNT_FAILED	" essais chou."
+# define DEF_COUNTS_FAILED	" essais chous."
 #else
 #if defined NL
 # define DEF_NAME	"Naam: "
 # define DEF_PASS	"Wachtwoord: "
 # define DEF_VALID	"Aan het checken ..."
 # define DEF_INVALID	"Ongeldig wachtwoord."
-# define DEF_INFO	"Geef wachtwoord om te ontgrendelen ; selecteer het icoon om te vergendelen."
+# define DEF_INFO	"Geef wachtwoord om te ontgrendelen ; selecteer het icoon om te vergrendelen."
+# define DEF_COUNT_FAILED	" mislukte poging."
+# define DEF_COUNTS_FAILED	" mislukte pogingen."
 #else
 #if defined JP
 # include "resource-msg-jp.h"
@@ -187,6 +191,8 @@ static int  descr();
 # define DEF_VALID	"Validating login..."
 # define DEF_INVALID	"Invalid login."
 # define DEF_INFO	"Enter password to unlock; select icon to lock."
+# define DEF_COUNT_FAILED	" failed attempt."
+# define DEF_COUNTS_FAILED	" failed attempts."
 #endif
 #endif
 #endif
@@ -719,7 +725,6 @@ char       *modulepath;
 #endif
 
 static char *erasemodename;
-int         erasemode;
 int         erasedelay, erasetime;
 Bool        nolock;
 Bool        inwindow;
@@ -796,9 +801,10 @@ char       *text_chall;
 char       *text_info;
 char       *text_valid;
 char       *text_invalid;
+char	   *failed_attempt;
+char	   *failed_attempts;
 char       *geometry;
 char       *icongeometry;
-
 #ifdef FX
 char       *glgeometry;
 
@@ -912,6 +918,8 @@ static argtype genvars[] =
 	{(caddr_t *) & text_info, (char *) "info", (char *) "Info", (char *) DEF_INFO, t_String},
      {(caddr_t *) & text_valid, (char *) "validate", (char *) "Validate", (char *) DEF_VALID, t_String},
    {(caddr_t *) & text_invalid, (char *) "invalid", (char *) "Invalid", (char *) DEF_INVALID, t_String},
+   {(caddr_t *) & failed_attempt, (char *) "attempt", (char *) "Attempt", (char *) DEF_COUNT_FAILED, t_String},
+   {(caddr_t *) & failed_attempts, (char *) "attempts", (char *) "Attempts", (char *) DEF_COUNTS_FAILED, t_String},
     {(caddr_t *) & geometry, (char *) "geometry", (char *) "Geometry", (char *) DEF_GEOMETRY, t_String},
 	{(caddr_t *) & icongeometry, (char *) "icongeometry", (char *) "IconGeometry", (char *) DEF_ICONGEOMETRY, t_String},
 #ifdef FX
@@ -1206,8 +1214,8 @@ GetResource(XrmDatabase database,
 	(void) sprintf(fullName, "%s.%s", parentName, name);
 	(void) sprintf(fullClassName, "%s.%s", parentClassName, className);
 	temp = XrmGetResource(database, fullName, fullClassName, &type, &value);
-	(void) free((void *) fullName);
-	(void) free((void *) fullClassName);
+	free(fullName);
+	free(fullClassName);
 
 	if (temp) {
 		string = value.addr;
@@ -1238,7 +1246,7 @@ GetResource(XrmDatabase database,
 					(void) sprintf(buf,
 						       "%s: GetResource - could not allocate memory", ProgramName);
 					error(buf);
-					(void) free((void *) buf);	/* Should never get here */
+					free(buf);	/* Should never get here */
 				}
 				(void) strncpy(s, string, len);
 				s[len] = '\0';
@@ -1259,7 +1267,7 @@ GetResource(XrmDatabase database,
 				      !strcmp(buffer, "yes")) ? True : False;
 			break;
 	}
-	(void) free((void *) buffer);
+	free(buffer);
 }
 
 static      XrmDatabase
@@ -1368,7 +1376,7 @@ parsefilepath(char *xfilesearchpath, const char *typeName,
 			*dst = '\0';
 		}
 	}
-	(void) free((void *) appdefaults);
+	free(appdefaults);
 	return database;
 }
 
@@ -1467,7 +1475,7 @@ openDisplay(Display ** displayp)
 			     "%s: unable to open display %s.\n", ProgramName,
 			       ((displayname) ? displayname : ""));
 		error(buf);
-		(void) free((void *) buf);	/* Should never get here */
+		free(buf);	/* Should never get here */
 	}
 	displayname = DisplayString(*displayp);
 }
@@ -1511,7 +1519,7 @@ extern int  gethostname(char *, size_t);
 		(void) sprintf(buf,
 			   "%s: Can not get local hostname.\n", ProgramName);
 		error(buf);
-		(void) free((void *) buf);	/* Should never get here */
+		free(buf);	/* Should never get here */
 	}
 #ifdef VMS
 	if (!remote && ((displayname[0] == '_') |
@@ -1541,7 +1549,7 @@ extern int  gethostname(char *, size_t);
 				(void) sprintf(buf,
 					       "%s: can not lock %s\n", ProgramName, displayname);
 				error(buf);
-				(void) free((void *) buf);	/* Should never get here */
+				free(buf);	/* Should never get here */
 			}
 		}
 	} else {
@@ -1558,7 +1566,7 @@ extern int  gethostname(char *, size_t);
 				 "%s: Malformed -display argument, \"%s\"\n",
 					       ProgramName, displayname);
 				error(buf);
-				(void) free((void *) buf);	/* Should never get here */
+				free(buf);	/* Should never get here */
 			}
 			if (!remote && n
 			    && strncmp(displayname, "unix", n)
@@ -1588,7 +1596,7 @@ extern int  gethostname(char *, size_t);
 							       "%s: can not lock %s's display\n",
 						   ProgramName, displayname);
 						error(buf);
-						(void) free((void *) buf);	/* Should never get here */
+						free(buf);	/* Should never get here */
 					}
 				}
 			}
@@ -1651,7 +1659,7 @@ getServerResources(Display * display, char *homeenv,
 #else
 		(void) XrmMergeDatabases(XrmGetFileDatabase(buf), RDB);
 #endif
-		(void) free((void *) buf);
+		free(buf);
 	}
 #ifdef CUSTOMIZATION
 	if (*serverDB)
@@ -1710,7 +1718,7 @@ getAppResources(char *homeenv, char **custom, XrmDatabase * RDB,
 	userDB = parsefilepath(userpath, "app-defaults", classname, *custom);
 
 	if (userfile)
-		(void) free((void *) userfile);
+		free(userfile);
 
 	(void) XrmMergeDatabases(applicationDB, RDB);
 	(void) XrmMergeDatabases(userDB, RDB);
@@ -1763,7 +1771,7 @@ extern void XlockrmParseCommand(
 extern int  fullLock();
 
 #endif
-extern int  erasemodefromname(char *name);
+extern void erasemodefromname(char *name, Bool verbose);
 
 
 void
@@ -1984,7 +1992,7 @@ getResources(Display ** displayp, int argc, char **argv)
 				     modevars[j].type, buf, modevars[j].var);
 			}
 			if (buf) {
-				(void) free((void *) buf);
+				free(buf);
 				buf = (char *) NULL;
 			}
 		}
@@ -2086,17 +2094,14 @@ getResources(Display ** displayp, int argc, char **argv)
 			(void) fprintf(stderr, "Using visual class %s\n",
 				       nameOfVisualClass(VisualClassWanted));
 	}
-	if (!erasemodename || !*erasemodename || !strcmp(erasemodename,
+	erasemodefromname(erasemodename, verbose);
+	/* if (!erasemodename || !*erasemodename || !strcmp(erasemodename,
 							 "default")) {
 		erasemode = -1;
 		if (verbose)
 			(void) fprintf(stderr, "Using random erase mode\n");
 	} else {
-		erasemode = erasemodefromname(erasemodename);
-		if (verbose)
-			(void) fprintf(stderr, "Using erase mode %s\n",
-				       erasemodename);
-	}
+	}*/
 #if HAVE_DIRENT_H
 	/* Evaluate bitmap */
 	if (bitmap && strcmp(bitmap, DEF_BITMAP)) {
@@ -2106,9 +2111,9 @@ getResources(Display ** displayp, int argc, char **argv)
 
 			for (num = 0; num < num_list; num++) {
 				if  (image_list[num])
-					(void) free((void *) image_list[num]);
+					free(image_list[num]);
 			}
-			(void) free((void *) image_list);
+			free(image_list);
 			image_list = (struct dirent **) NULL;
 		}
 		images_list = (struct dirent ***) malloc(sizeof (struct dirent **));
@@ -2116,7 +2121,7 @@ getResources(Display ** displayp, int argc, char **argv)
 		num_list = scan_dir(directory_r, images_list, sel_image, NULL);
 		image_list = *images_list;
 		if (images_list) {
-			(void) free((void *) images_list);
+			free(images_list);
 			images_list = (struct dirent ***) NULL;
 		}
 		if (debug)
@@ -2130,8 +2135,8 @@ getResources(Display ** displayp, int argc, char **argv)
 		num_list = 0;
 	}
 #endif
-	(void) free((void *) modename);
-	(void) free((void *) modeclassname);
+	free(modename);
+	free(modeclassname);
 }
 
 extern char * old_default_mode;
@@ -2163,8 +2168,6 @@ checkResources(void)
 		/* count and size we allow negative to mean randomize up to that number */
 		if (delay < 0)
 			Syntax("-delay argument must not be negative.");
-		if (cycles < 0)
-			Syntax("-cycles argument must not be negative.");
 		if (ncolors < 2 || ncolors > 200)
 			Syntax("-ncolors argument must be between 2 and 200.");
 		if (saturation < 0.0 || saturation > 1.0)
